"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub,
    ctx,
    accelerator_arn: str,
    endpoint_group_arn: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Provides a complete mapping from the public accelerator IP address and port to destination EC2 instance IP addresses and ports in the virtual public cloud (VPC) subnet endpoint for a custom routing accelerator. For each subnet endpoint that you add, Global Accelerator creates a new static port mapping for the accelerator. The port mappings don't change after Global Accelerator generates them, so you can retrieve and cache the full mapping on your servers.  If you remove a subnet from your accelerator, Global Accelerator removes (reclaims) the port mappings. If you add a subnet to your accelerator, Global Accelerator creates new port mappings (the existing ones don't change). If you add or remove EC2 instances in your subnet, the port mappings don't change, because the mappings are created when you add the subnet to Global Accelerator. The mappings also include a flag for each destination denoting which destination IP addresses and ports are allowed or denied traffic.

    Args:
        accelerator_arn(str): The Amazon Resource Name (ARN) of the accelerator to list the custom routing port mappings for.
        endpoint_group_arn(str, optional): The Amazon Resource Name (ARN) of the endpoint group to list the custom routing port mappings for. Defaults to None.
        max_results(int, optional): The number of destination port mappings that you want to return with this call. The default value is 10. Defaults to None.
        next_token(str, optional): The token for the next set of results. You receive this token from a previous call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.globalaccelerator.custom_routing.port_mapping.init.list_all(
                ctx, accelerator_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.globalaccelerator.custom_routing.port_mapping.init.list_all accelerator_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="globalaccelerator",
        operation="list_custom_routing_port_mappings",
        op_kwargs={
            "AcceleratorArn": accelerator_arn,
            "EndpointGroupArn": endpoint_group_arn,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(
    hub,
    ctx,
    finding_identifiers: List,
    note: Dict = None,
    severity: Dict = None,
    verification_state: str = None,
    confidence: int = None,
    criticality: int = None,
    types: List = None,
    user_defined_fields: Dict = None,
    workflow: Dict = None,
    related_findings: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Used by Security Hub customers to update information about their investigation into a finding. Requested by administrator accounts or member accounts. Administrator accounts can update findings for their account and their member accounts. Member accounts can update findings for their account. Updates from BatchUpdateFindings do not affect the value of UpdatedAt for a finding. Administrator and member accounts can use BatchUpdateFindings to update the following finding fields and objects.    Confidence     Criticality     Note     RelatedFindings     Severity     Types     UserDefinedFields     VerificationState     Workflow    You can configure IAM policies to restrict access to fields and field values. For example, you might not want member accounts to be able to suppress findings or change the finding severity. See Configuring access to BatchUpdateFindings in the Security Hub User Guide.

    Args:
        finding_identifiers(List): The list of findings to update. BatchUpdateFindings can be used to update up to 100 findings at a time. For each finding, the list provides the finding identifier and the ARN of the finding provider.
        note(Dict, optional): The updated note. Defaults to None.
        severity(Dict, optional): Used to update the finding severity. Defaults to None.
        verification_state(str, optional): Indicates the veracity of a finding. The available values for VerificationState are as follows.    UNKNOWN – The default disposition of a security finding    TRUE_POSITIVE – The security finding is confirmed    FALSE_POSITIVE – The security finding was determined to be a false alarm    BENIGN_POSITIVE – A special case of TRUE_POSITIVE where the finding doesn't pose any threat, is expected, or both  . Defaults to None.
        confidence(int, optional): The updated value for the finding confidence. Confidence is defined as the likelihood that a finding accurately identifies the behavior or issue that it was intended to identify. Confidence is scored on a 0-100 basis using a ratio scale, where 0 means zero percent confidence and 100 means 100 percent confidence. Defaults to None.
        criticality(int, optional): The updated value for the level of importance assigned to the resources associated with the findings. A score of 0 means that the underlying resources have no criticality, and a score of 100 is reserved for the most critical resources. . Defaults to None.
        types(List, optional): One or more finding types in the format of namespace/category/classifier that classify a finding. Valid namespace values are as follows.   Software and Configuration Checks   TTPs   Effects   Unusual Behaviors   Sensitive Data Identifications   . Defaults to None.
        user_defined_fields(Dict, optional): A list of name/value string pairs associated with the finding. These are custom, user-defined fields added to a finding. Defaults to None.
        workflow(Dict, optional): Used to update the workflow status of a finding. The workflow status indicates the progress of the investigation into the finding. . Defaults to None.
        related_findings(List, optional): A list of findings that are related to the updated findings. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.securityhub.update_finding.batch(ctx, finding_identifiers=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.securityhub.update_finding.batch finding_identifiers=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="securityhub",
        operation="batch_update_findings",
        op_kwargs={
            "FindingIdentifiers": finding_identifiers,
            "Note": note,
            "Severity": severity,
            "VerificationState": verification_state,
            "Confidence": confidence,
            "Criticality": criticality,
            "Types": types,
            "UserDefinedFields": user_defined_fields,
            "Workflow": workflow,
            "RelatedFindings": related_findings,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get_all(hub, ctx, trail_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes the settings for the Insights event selectors that you configured for your trail. GetInsightSelectors shows if CloudTrail Insights event logging is enabled on the trail, and if it is, which insight types are enabled. If you run GetInsightSelectors on a trail that does not have Insights events enabled, the operation throws the exception InsightNotEnabledException  For more information, see Logging CloudTrail Insights Events for Trails  in the AWS CloudTrail User Guide.

    Args:
        trail_name(str): Specifies the name of the trail or trail ARN. If you specify a trail name, the string must meet the following requirements:   Contain only ASCII letters (a-z, A-Z), numbers (0-9), periods (.), underscores (_), or dashes (-)   Start with a letter or number, and end with a letter or number   Be between 3 and 128 characters   Have no adjacent periods, underscores or dashes. Names like my-_namespace and my--namespace are not valid.   Not be in IP address format (for example, 192.168.5.4)   If you specify a trail ARN, it must be in the format:  arn:aws:cloudtrail:us-east-2:123456789012:trail/MyTrail .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudtrail.insight_selector.get_all(ctx, trail_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudtrail.insight_selector.get_all trail_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudtrail",
        operation="get_insight_selectors",
        op_kwargs={"TrailName": trail_name},
    )


async def put_multiple(hub, ctx, trail_name: str, insight_selectors: List) -> Dict:
    r"""
    **Autogenerated function**

    Lets you enable Insights event logging by specifying the Insights selectors that you want to enable on an existing trail. You also use PutInsightSelectors to turn off Insights event logging, by passing an empty list of insight types. In this release, only ApiCallRateInsight is supported as an Insights selector.

    Args:
        trail_name(str): The name of the CloudTrail trail for which you want to change or add Insights selectors.
        insight_selectors(List): A JSON string that contains the insight types you want to log on a trail. In this release, only ApiCallRateInsight is supported as an insight type.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudtrail.insight_selector.put_multiple(
                ctx, trail_name=value, insight_selectors=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudtrail.insight_selector.put_multiple trail_name=value, insight_selectors=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudtrail",
        operation="put_insight_selectors",
        op_kwargs={"TrailName": trail_name, "InsightSelectors": insight_selectors},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, month: int, year: int) -> Dict:
    r"""
    **Autogenerated function**

    Returns the number of minutes used by account.

    Args:
        month(int): The month being requested, with a value of 1-12.
        year(int): The year being requested, in the format of YYYY.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.groundstation.minute_usage.get(ctx, month=value, year=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.groundstation.minute_usage.get month=value, year=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="groundstation",
        operation="get_minute_usage",
        op_kwargs={"month": month, "year": year},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, id_: str, document: str, comment: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new version of an existing traffic policy. When you create a new version of a traffic policy, you specify the ID of the traffic policy that you want to update and a JSON-formatted document that describes the new version. You use traffic policies to create multiple DNS resource record sets for one domain name (such as example.com) or one subdomain name (such as www.example.com). You can create a maximum of 1000 versions of a traffic policy. If you reach the limit and need to create another version, you'll need to start a new traffic policy.

    Args:
        id_(str): The ID of the traffic policy for which you want to create a new version.
        document(str): The definition of this version of the traffic policy, in JSON format. You specified the JSON in the CreateTrafficPolicyVersion request. For more information about the JSON format, see CreateTrafficPolicy.
        comment(str, optional): The comment that you specified in the CreateTrafficPolicyVersion request, if any. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53.traffic_policy.version.create(
                ctx, id_=value, document=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53.traffic_policy.version.create id_=value, document=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53",
        operation="create_traffic_policy_version",
        op_kwargs={"Id": id_, "Document": document, "Comment": comment},
    )


async def list_all(
    hub, ctx, id_: str, traffic_policy_version_marker: str = None, max_items: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about all of the versions for a specified traffic policy. Traffic policy versions are listed in numerical order by VersionNumber.

    Args:
        id_(str): Specify the value of Id of the traffic policy for which you want to list all versions.
        traffic_policy_version_marker(str, optional): For your first request to ListTrafficPolicyVersions, don't include the TrafficPolicyVersionMarker parameter. If you have more traffic policy versions than the value of MaxItems, ListTrafficPolicyVersions returns only the first group of MaxItems versions. To get more traffic policy versions, submit another ListTrafficPolicyVersions request. For the value of TrafficPolicyVersionMarker, specify the value of TrafficPolicyVersionMarker in the previous response. Defaults to None.
        max_items(str, optional): The maximum number of traffic policy versions that you want Amazon Route 53 to include in the response body for this request. If the specified traffic policy has more than MaxItems versions, the value of IsTruncated in the response is true, and the value of the TrafficPolicyVersionMarker element is the ID of the first version that Route 53 will return if you submit another request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53.traffic_policy.version.list_all(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53.traffic_policy.version.list_all id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53",
        operation="list_traffic_policy_versions",
        op_kwargs={
            "Id": id_,
            "TrafficPolicyVersionMarker": traffic_policy_version_marker,
            "MaxItems": max_items,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub, ctx, resource_group_name: str, component_name: str, resource_list: List
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a custom component by grouping similar standalone instances to monitor.

    Args:
        resource_group_name(str): The name of the resource group.
        component_name(str): The name of the component.
        resource_list(List): The list of resource ARNs that belong to the component.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.application_insight.component.init.create(
                ctx, resource_group_name=value, component_name=value, resource_list=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.application_insight.component.init.create resource_group_name=value, component_name=value, resource_list=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="application-insights",
        operation="create_component",
        op_kwargs={
            "ResourceGroupName": resource_group_name,
            "ComponentName": component_name,
            "ResourceList": resource_list,
        },
    )


async def delete(hub, ctx, resource_group_name: str, component_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Ungroups a custom component. When you ungroup custom components, all applicable monitors that are set up for the component are removed and the instances revert to their standalone status.

    Args:
        resource_group_name(str): The name of the resource group.
        component_name(str): The name of the component.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.application_insight.component.init.delete(
                ctx, resource_group_name=value, component_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.application_insight.component.init.delete resource_group_name=value, component_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="application-insights",
        operation="delete_component",
        op_kwargs={
            "ResourceGroupName": resource_group_name,
            "ComponentName": component_name,
        },
    )


async def describe(hub, ctx, resource_group_name: str, component_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes a component and lists the resources that are grouped together in a component.

    Args:
        resource_group_name(str): The name of the resource group.
        component_name(str): The name of the component.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.application_insight.component.init.describe(
                ctx, resource_group_name=value, component_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.application_insight.component.init.describe resource_group_name=value, component_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="application-insights",
        operation="describe_component",
        op_kwargs={
            "ResourceGroupName": resource_group_name,
            "ComponentName": component_name,
        },
    )


async def list_all(
    hub, ctx, resource_group_name: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the auto-grouped, standalone, and custom components of the application.

    Args:
        resource_group_name(str): The name of the resource group.
        max_results(int, optional): The maximum number of results to return in a single call. To retrieve the remaining results, make another call with the returned NextToken value. Defaults to None.
        next_token(str, optional): The token to request the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.application_insight.component.init.list_all(
                ctx, resource_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.application_insight.component.init.list_all resource_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="application-insights",
        operation="list_components",
        op_kwargs={
            "ResourceGroupName": resource_group_name,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def update(
    hub,
    ctx,
    resource_group_name: str,
    component_name: str,
    new_component_name: str = None,
    resource_list: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the custom component name and/or the list of resources that make up the component.

    Args:
        resource_group_name(str): The name of the resource group.
        component_name(str): The name of the component.
        new_component_name(str, optional): The new name of the component. Defaults to None.
        resource_list(List, optional): The list of resource ARNs that belong to the component. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.application_insight.component.init.update(
                ctx, resource_group_name=value, component_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.application_insight.component.init.update resource_group_name=value, component_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="application-insights",
        operation="update_component",
        op_kwargs={
            "ResourceGroupName": resource_group_name,
            "ComponentName": component_name,
            "NewComponentName": new_component_name,
            "ResourceList": resource_list,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def submit(
    hub,
    ctx,
    cluster: str = None,
    task: str = None,
    status: str = None,
    reason: str = None,
    containers: List = None,
    attachments: List = None,
    managed_agents: List = None,
    pull_started_at: str = None,
    pull_stopped_at: str = None,
    execution_stopped_at: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     This action is only used by the Amazon ECS agent, and it is not intended for use outside of the agent.  Sent to acknowledge that a task changed states.

    Args:
        cluster(str, optional): The short name or full Amazon Resource Name (ARN) of the cluster that hosts the task. Defaults to None.
        task(str, optional): The task ID or full ARN of the task in the state change request. Defaults to None.
        status(str, optional): The status of the state change request. Defaults to None.
        reason(str, optional): The reason for the state change request. Defaults to None.
        containers(List, optional): Any containers associated with the state change request. Defaults to None.
        attachments(List, optional): Any attachments associated with the state change request. Defaults to None.
        managed_agents(List, optional): The details for the managed agent associated with the task. Defaults to None.
        pull_started_at(str, optional): The Unix timestamp for when the container image pull began. Defaults to None.
        pull_stopped_at(str, optional): The Unix timestamp for when the container image pull completed. Defaults to None.
        execution_stopped_at(str, optional): The Unix timestamp for when the task execution stopped. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecs.task.state_change.submit(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecs.task.state_change.submit
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecs",
        operation="submit_task_state_change",
        op_kwargs={
            "cluster": cluster,
            "task": task,
            "status": status,
            "reason": reason,
            "containers": containers,
            "attachments": attachments,
            "managedAgents": managed_agents,
            "pullStartedAt": pull_started_at,
            "pullStoppedAt": pull_stopped_at,
            "executionStoppedAt": execution_stopped_at,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, database_input: Dict, catalog_id: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new database in a Data Catalog.

    Args:
        catalog_id(str, optional): The ID of the Data Catalog in which to create the database. If none is provided, the Amazon Web Services account ID is used by default. Defaults to None.
        database_input(Dict): The metadata for the database.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.database.create(ctx, database_input=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.database.create database_input=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="create_database",
        op_kwargs={"CatalogId": catalog_id, "DatabaseInput": database_input},
    )


async def delete(hub, ctx, name: str, catalog_id: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Removes a specified database from a Data Catalog.  After completing this operation, you no longer have access to the tables (and all table versions and partitions that might belong to the tables) and the user-defined functions in the deleted database. Glue deletes these "orphaned" resources asynchronously in a timely manner, at the discretion of the service. To ensure the immediate deletion of all related resources, before calling DeleteDatabase, use DeleteTableVersion or BatchDeleteTableVersion, DeletePartition or BatchDeletePartition, DeleteUserDefinedFunction, and DeleteTable or BatchDeleteTable, to delete any resources that belong to the database.

    Args:
        catalog_id(str, optional): The ID of the Data Catalog in which the database resides. If none is provided, the Amazon Web Services account ID is used by default. Defaults to None.
        name(str): The name of the database to delete. For Hive compatibility, this must be all lowercase.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.database.delete(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.database.delete name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="delete_database",
        op_kwargs={"CatalogId": catalog_id, "Name": name},
    )


async def get(hub, ctx, name: str, catalog_id: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the definition of a specified database.

    Args:
        catalog_id(str, optional): The ID of the Data Catalog in which the database resides. If none is provided, the Amazon Web Services account ID is used by default. Defaults to None.
        name(str): The name of the database to retrieve. For Hive compatibility, this should be all lowercase.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.database.get(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.database.get name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="get_database",
        op_kwargs={"CatalogId": catalog_id, "Name": name},
    )


async def get_all(
    hub,
    ctx,
    catalog_id: str = None,
    next_token: str = None,
    max_results: int = None,
    resource_share_type: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves all databases defined in a given Data Catalog.

    Args:
        catalog_id(str, optional): The ID of the Data Catalog from which to retrieve Databases. If none is provided, the Amazon Web Services account ID is used by default. Defaults to None.
        next_token(str, optional): A continuation token, if this is a continuation call. Defaults to None.
        max_results(int, optional): The maximum number of databases to return in one response. Defaults to None.
        resource_share_type(str, optional): Allows you to specify that you want to list the databases shared with your account. The allowable values are FOREIGN or ALL.    If set to FOREIGN, will list the databases shared with your account.    If set to ALL, will list the databases shared with your account, as well as the databases in yor local account.   . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.database.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.database.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="get_databases",
        op_kwargs={
            "CatalogId": catalog_id,
            "NextToken": next_token,
            "MaxResults": max_results,
            "ResourceShareType": resource_share_type,
        },
    )


async def update(
    hub, ctx, name: str, database_input: Dict, catalog_id: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an existing database definition in a Data Catalog.

    Args:
        catalog_id(str, optional): The ID of the Data Catalog in which the metadata database resides. If none is provided, the Amazon Web Services account ID is used by default. Defaults to None.
        name(str): The name of the database to update in the catalog. For Hive compatibility, this is folded to lowercase.
        database_input(Dict): A DatabaseInput object specifying the new definition of the metadata database in the catalog.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.database.update(ctx, name=value, database_input=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.database.update name=value, database_input=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="update_database",
        op_kwargs={
            "CatalogId": catalog_id,
            "Name": name,
            "DatabaseInput": database_input,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def request(
    hub,
    ctx,
    availability_zone_group: str = None,
    block_duration_minutes: int = None,
    client_token: str = None,
    dry_run: bool = None,
    instance_count: int = None,
    launch_group: str = None,
    launch_specification: Dict = None,
    spot_price: str = None,
    type_: str = None,
    valid_from: str = None,
    valid_until: str = None,
    tag_specifications: List = None,
    instance_interruption_behavior: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a Spot Instance request. For more information, see Spot Instance requests in the Amazon EC2 User Guide for Linux Instances.

    Args:
        availability_zone_group(str, optional): The user-specified name for a logical grouping of requests. When you specify an Availability Zone group in a Spot Instance request, all Spot Instances in the request are launched in the same Availability Zone. Instance proximity is maintained with this parameter, but the choice of Availability Zone is not. The group applies only to requests for Spot Instances of the same instance type. Any additional Spot Instance requests that are specified with the same Availability Zone group name are launched in that same Availability Zone, as long as at least one instance from the group is still active. If there is no active instance running in the Availability Zone group that you specify for a new Spot Instance request (all instances are terminated, the request is expired, or the maximum price you specified falls below current Spot price), then Amazon EC2 launches the instance in any Availability Zone where the constraint can be met. Consequently, the subsequent set of Spot Instances could be placed in a different zone from the original request, even if you specified the same Availability Zone group. Default: Instances are launched in any available Availability Zone. Defaults to None.
        block_duration_minutes(int, optional): Deprecated. Defaults to None.
        client_token(str, optional): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see How to Ensure Idempotency in the Amazon EC2 User Guide for Linux Instances. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        instance_count(int, optional): The maximum number of Spot Instances to launch. Default: 1. Defaults to None.
        launch_group(str, optional): The instance launch group. Launch groups are Spot Instances that launch together and terminate together. Default: Instances are launched and terminated individually. Defaults to None.
        launch_specification(Dict, optional): The launch specification. Defaults to None.
        spot_price(str, optional): The maximum price per hour that you are willing to pay for a Spot Instance. The default is the On-Demand price. Defaults to None.
        type_(str, optional): The Spot Instance request type. Default: one-time . Defaults to None.
        valid_from(str, optional): The start date of the request. If this is a one-time request, the request becomes active at this date and time and remains active until all instances launch, the request expires, or the request is canceled. If the request is persistent, the request becomes active at this date and time and remains active until it expires or is canceled. The specified start date and time cannot be equal to the current date and time. You must specify a start date and time that occurs after the current date and time. Defaults to None.
        valid_until(str, optional): The end date of the request, in UTC format (YYYY-MM-DDTHH:MM:SSZ).   For a persistent request, the request remains active until the ValidUntil date and time is reached. Otherwise, the request remains active until you cancel it.    For a one-time request, the request remains active until all instances launch, the request is canceled, or the ValidUntil date and time is reached. By default, the request is valid for 7 days from the date the request was created.  . Defaults to None.
        tag_specifications(List, optional): The key-value pair for tagging the Spot Instance request on creation. The value for ResourceType must be spot-instances-request, otherwise the Spot Instance request fails. To tag the Spot Instance request after it has been created, see CreateTags. . Defaults to None.
        instance_interruption_behavior(str, optional): The behavior when a Spot Instance is interrupted. The default is terminate. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.spot.instance.init.request(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.spot.instance.init.request
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="request_spot_instances",
        op_kwargs={
            "AvailabilityZoneGroup": availability_zone_group,
            "BlockDurationMinutes": block_duration_minutes,
            "ClientToken": client_token,
            "DryRun": dry_run,
            "InstanceCount": instance_count,
            "LaunchGroup": launch_group,
            "LaunchSpecification": launch_specification,
            "SpotPrice": spot_price,
            "Type": type_,
            "ValidFrom": valid_from,
            "ValidUntil": valid_until,
            "TagSpecifications": tag_specifications,
            "InstanceInterruptionBehavior": instance_interruption_behavior,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def attach(
    hub, ctx, auto_scaling_group_name: str, load_balancer_names: List
) -> Dict:
    r"""
    **Autogenerated function**

     To attach an Application Load Balancer, Network Load Balancer, or Gateway Load Balancer, use the AttachLoadBalancerTargetGroups API operation instead.  Attaches one or more Classic Load Balancers to the specified Auto Scaling group. Amazon EC2 Auto Scaling registers the running instances with these Classic Load Balancers. To describe the load balancers for an Auto Scaling group, call the DescribeLoadBalancers API. To detach the load balancer from the Auto Scaling group, call the DetachLoadBalancers API. For more information, see Elastic Load Balancing and Amazon EC2 Auto Scaling in the Amazon EC2 Auto Scaling User Guide.

    Args:
        auto_scaling_group_name(str): The name of the Auto Scaling group.
        load_balancer_names(List): The names of the load balancers. You can specify up to 10 load balancers.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling.load_balancer.init.attach(
                ctx, auto_scaling_group_name=value, load_balancer_names=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling.load_balancer.init.attach auto_scaling_group_name=value, load_balancer_names=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling",
        operation="attach_load_balancers",
        op_kwargs={
            "AutoScalingGroupName": auto_scaling_group_name,
            "LoadBalancerNames": load_balancer_names,
        },
    )


async def describe_all(
    hub,
    ctx,
    auto_scaling_group_name: str,
    next_token: str = None,
    max_records: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about the load balancers for the specified Auto Scaling group. This operation describes only Classic Load Balancers. If you have Application Load Balancers, Network Load Balancers, or Gateway Load Balancers, use the DescribeLoadBalancerTargetGroups API instead. To determine the availability of registered instances, use the State element in the response. When you attach a load balancer to an Auto Scaling group, the initial State value is Adding. The state transitions to Added after all Auto Scaling instances are registered with the load balancer. If Elastic Load Balancing health checks are enabled for the Auto Scaling group, the state transitions to InService after at least one Auto Scaling instance passes the health check. When the load balancer is in the InService state, Amazon EC2 Auto Scaling can terminate and replace any instances that are reported as unhealthy. If no registered instances pass the health checks, the load balancer doesn't enter the InService state.  Load balancers also have an InService state if you attach them in the CreateAutoScalingGroup API call. If your load balancer state is InService, but it is not working properly, check the scaling activities by calling DescribeScalingActivities and take any corrective actions necessary. For help with failed health checks, see Troubleshooting Amazon EC2 Auto Scaling: Health checks in the Amazon EC2 Auto Scaling User Guide. For more information, see Elastic Load Balancing and Amazon EC2 Auto Scaling in the Amazon EC2 Auto Scaling User Guide.

    Args:
        auto_scaling_group_name(str): The name of the Auto Scaling group.
        next_token(str, optional): The token for the next set of items to return. (You received this token from a previous call.). Defaults to None.
        max_records(int, optional): The maximum number of items to return with this call. The default value is 100 and the maximum value is 100. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling.load_balancer.init.describe_all(
                ctx, auto_scaling_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling.load_balancer.init.describe_all auto_scaling_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling",
        operation="describe_load_balancers",
        op_kwargs={
            "AutoScalingGroupName": auto_scaling_group_name,
            "NextToken": next_token,
            "MaxRecords": max_records,
        },
    )


async def detach(
    hub, ctx, auto_scaling_group_name: str, load_balancer_names: List
) -> Dict:
    r"""
    **Autogenerated function**

    Detaches one or more Classic Load Balancers from the specified Auto Scaling group. This operation detaches only Classic Load Balancers. If you have Application Load Balancers, Network Load Balancers, or Gateway Load Balancers, use the DetachLoadBalancerTargetGroups API instead. When you detach a load balancer, it enters the Removing state while deregistering the instances in the group. When all instances are deregistered, then you can no longer describe the load balancer using the DescribeLoadBalancers API call. The instances remain running.

    Args:
        auto_scaling_group_name(str): The name of the Auto Scaling group.
        load_balancer_names(List): The names of the load balancers. You can specify up to 10 load balancers.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling.load_balancer.init.detach(
                ctx, auto_scaling_group_name=value, load_balancer_names=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling.load_balancer.init.detach auto_scaling_group_name=value, load_balancer_names=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling",
        operation="detach_load_balancers",
        op_kwargs={
            "AutoScalingGroupName": auto_scaling_group_name,
            "LoadBalancerNames": load_balancer_names,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(hub, ctx, directory_arn: str, operations: List) -> Dict:
    r"""
    **Autogenerated function**

    Performs all the write operations in a batch. Either all the operations succeed or none.

    Args:
        directory_arn(str): The Amazon Resource Name (ARN) that is associated with the Directory. For more information, see arns.
        operations(List): A list of operations that are part of the batch.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.clouddirectory.write.batch(
                ctx, directory_arn=value, operations=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.clouddirectory.write.batch directory_arn=value, operations=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="clouddirectory",
        operation="batch_write",
        op_kwargs={"DirectoryArn": directory_arn, "Operations": operations},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    backup_vault_name: str,
    backup_vault_tags: Dict = None,
    encryption_key_arn: str = None,
    creator_request_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a logical container where backups are stored. A CreateBackupVault request includes a name, optionally one or more resource tags, an encryption key, and a request ID.  Sensitive data, such as passport numbers, should not be included the name of a backup vault.

    Args:
        backup_vault_name(str): The name of a logical container where backups are stored. Backup vaults are identified by names that are unique to the account used to create them and the AWS Region where they are created. They consist of letters, numbers, and hyphens.
        backup_vault_tags(Dict, optional): Metadata that you can assign to help organize the resources that you create. Each tag is a key-value pair. Defaults to None.
        encryption_key_arn(str, optional): The server-side encryption key that is used to protect your backups; for example, arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab. Defaults to None.
        creator_request_id(str, optional): A unique string that identifies the request and allows failed requests to be retried without the risk of running the operation twice. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.backup.backup.vault.init.create(ctx, backup_vault_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.backup.backup.vault.init.create backup_vault_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="backup",
        operation="create_backup_vault",
        op_kwargs={
            "BackupVaultName": backup_vault_name,
            "BackupVaultTags": backup_vault_tags,
            "EncryptionKeyArn": encryption_key_arn,
            "CreatorRequestId": creator_request_id,
        },
    )


async def delete(hub, ctx, backup_vault_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the backup vault identified by its name. A vault can be deleted only if it is empty.

    Args:
        backup_vault_name(str): The name of a logical container where backups are stored. Backup vaults are identified by names that are unique to the account used to create them and the AWS Region where they are created. They consist of lowercase letters, numbers, and hyphens.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.backup.backup.vault.init.delete(ctx, backup_vault_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.backup.backup.vault.init.delete backup_vault_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="backup",
        operation="delete_backup_vault",
        op_kwargs={"BackupVaultName": backup_vault_name},
    )


async def describe(hub, ctx, backup_vault_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns metadata about a backup vault specified by its name.

    Args:
        backup_vault_name(str): The name of a logical container where backups are stored. Backup vaults are identified by names that are unique to the account used to create them and the AWS Region where they are created. They consist of lowercase letters, numbers, and hyphens.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.backup.backup.vault.init.describe(ctx, backup_vault_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.backup.backup.vault.init.describe backup_vault_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="backup",
        operation="describe_backup_vault",
        op_kwargs={"BackupVaultName": backup_vault_name},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of recovery point storage containers along with information about them.

    Args:
        next_token(str, optional): The next item following a partial list of returned items. For example, if a request is made to return maxResults number of items, NextToken allows you to return more items in your list starting at the location pointed to by the next token. Defaults to None.
        max_results(int, optional): The maximum number of items to be returned. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.backup.backup.vault.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.backup.backup.vault.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="backup",
        operation="list_backup_vaults",
        op_kwargs={"NextToken": next_token, "MaxResults": max_results},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(
    hub,
    ctx,
    service_namespace: str,
    scheduled_action_name: str,
    resource_id: str,
    scalable_dimension: str,
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified scheduled action for an Application Auto Scaling scalable target. For more information, see Delete a scheduled action in the Application Auto Scaling User Guide.

    Args:
        service_namespace(str): The namespace of the AWS service that provides the resource. For a resource provided by your own application or service, use custom-resource instead.
        scheduled_action_name(str): The name of the scheduled action.
        resource_id(str): The identifier of the resource associated with the scheduled action. This string consists of the resource type and unique identifier.   ECS service - The resource type is service and the unique identifier is the cluster name and service name. Example: service/default/sample-webapp.   Spot Fleet request - The resource type is spot-fleet-request and the unique identifier is the Spot Fleet request ID. Example: spot-fleet-request/sfr-73fbd2ce-aa30-494c-8788-1cee4EXAMPLE.   EMR cluster - The resource type is instancegroup and the unique identifier is the cluster ID and instance group ID. Example: instancegroup/j-2EEZNYKUA1NTV/ig-1791Y4E1L8YI0.   AppStream 2.0 fleet - The resource type is fleet and the unique identifier is the fleet name. Example: fleet/sample-fleet.   DynamoDB table - The resource type is table and the unique identifier is the table name. Example: table/my-table.   DynamoDB global secondary index - The resource type is index and the unique identifier is the index name. Example: table/my-table/index/my-table-index.   Aurora DB cluster - The resource type is cluster and the unique identifier is the cluster name. Example: cluster:my-db-cluster.   Amazon SageMaker endpoint variant - The resource type is variant and the unique identifier is the resource ID. Example: endpoint/my-end-point/variant/KMeansClustering.   Custom resources are not supported with a resource type. This parameter must specify the OutputValue from the CloudFormation template stack used to access the resources. The unique identifier is defined by the service provider. More information is available in our GitHub repository.   Amazon Comprehend document classification endpoint - The resource type and unique identifier are specified using the endpoint ARN. Example: arn:aws:comprehend:us-west-2:123456789012:document-classifier-endpoint/EXAMPLE.   Amazon Comprehend entity recognizer endpoint - The resource type and unique identifier are specified using the endpoint ARN. Example: arn:aws:comprehend:us-west-2:123456789012:entity-recognizer-endpoint/EXAMPLE.   Lambda provisioned concurrency - The resource type is function and the unique identifier is the function name with a function version or alias name suffix that is not $LATEST. Example: function:my-function:prod or function:my-function:1.   Amazon Keyspaces table - The resource type is table and the unique identifier is the table name. Example: keyspace/mykeyspace/table/mytable.   Amazon MSK cluster - The resource type and unique identifier are specified using the cluster ARN. Example: arn:aws:kafka:us-east-1:123456789012:cluster/demo-cluster-1/6357e0b2-0e6a-4b86-a0b4-70df934c2e31-5.  .
        scalable_dimension(str): The scalable dimension. This string consists of the service namespace, resource type, and scaling property.    ecs:service:DesiredCount - The desired task count of an ECS service.    ec2:spot-fleet-request:TargetCapacity - The target capacity of a Spot Fleet request.    elasticmapreduce:instancegroup:InstanceCount - The instance count of an EMR Instance Group.    appstream:fleet:DesiredCapacity - The desired capacity of an AppStream 2.0 fleet.    dynamodb:table:ReadCapacityUnits - The provisioned read capacity for a DynamoDB table.    dynamodb:table:WriteCapacityUnits - The provisioned write capacity for a DynamoDB table.    dynamodb:index:ReadCapacityUnits - The provisioned read capacity for a DynamoDB global secondary index.    dynamodb:index:WriteCapacityUnits - The provisioned write capacity for a DynamoDB global secondary index.    rds:cluster:ReadReplicaCount - The count of Aurora Replicas in an Aurora DB cluster. Available for Aurora MySQL-compatible edition and Aurora PostgreSQL-compatible edition.    sagemaker:variant:DesiredInstanceCount - The number of EC2 instances for an Amazon SageMaker model endpoint variant.    custom-resource:ResourceType:Property - The scalable dimension for a custom resource provided by your own application or service.    comprehend:document-classifier-endpoint:DesiredInferenceUnits - The number of inference units for an Amazon Comprehend document classification endpoint.    comprehend:entity-recognizer-endpoint:DesiredInferenceUnits - The number of inference units for an Amazon Comprehend entity recognizer endpoint.    lambda:function:ProvisionedConcurrency - The provisioned concurrency for a Lambda function.    cassandra:table:ReadCapacityUnits - The provisioned read capacity for an Amazon Keyspaces table.    cassandra:table:WriteCapacityUnits - The provisioned write capacity for an Amazon Keyspaces table.    kafka:broker-storage:VolumeSize - The provisioned volume size (in GiB) for brokers in an Amazon MSK cluster.  .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.application_autoscaling.scheduled_action.delete(
                ctx,
                service_namespace=value,
                scheduled_action_name=value,
                resource_id=value,
                scalable_dimension=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.application_autoscaling.scheduled_action.delete service_namespace=value, scheduled_action_name=value, resource_id=value, scalable_dimension=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="application-autoscaling",
        operation="delete_scheduled_action",
        op_kwargs={
            "ServiceNamespace": service_namespace,
            "ScheduledActionName": scheduled_action_name,
            "ResourceId": resource_id,
            "ScalableDimension": scalable_dimension,
        },
    )


async def describe_all(
    hub,
    ctx,
    service_namespace: str,
    scheduled_action_names: List = None,
    resource_id: str = None,
    scalable_dimension: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the Application Auto Scaling scheduled actions for the specified service namespace. You can filter the results using the ResourceId, ScalableDimension, and ScheduledActionNames parameters. For more information, see Scheduled scaling and Managing scheduled scaling in the Application Auto Scaling User Guide.

    Args:
        scheduled_action_names(List, optional): The names of the scheduled actions to describe. Defaults to None.
        service_namespace(str): The namespace of the AWS service that provides the resource. For a resource provided by your own application or service, use custom-resource instead.
        resource_id(str, optional): The identifier of the resource associated with the scheduled action. This string consists of the resource type and unique identifier.   ECS service - The resource type is service and the unique identifier is the cluster name and service name. Example: service/default/sample-webapp.   Spot Fleet request - The resource type is spot-fleet-request and the unique identifier is the Spot Fleet request ID. Example: spot-fleet-request/sfr-73fbd2ce-aa30-494c-8788-1cee4EXAMPLE.   EMR cluster - The resource type is instancegroup and the unique identifier is the cluster ID and instance group ID. Example: instancegroup/j-2EEZNYKUA1NTV/ig-1791Y4E1L8YI0.   AppStream 2.0 fleet - The resource type is fleet and the unique identifier is the fleet name. Example: fleet/sample-fleet.   DynamoDB table - The resource type is table and the unique identifier is the table name. Example: table/my-table.   DynamoDB global secondary index - The resource type is index and the unique identifier is the index name. Example: table/my-table/index/my-table-index.   Aurora DB cluster - The resource type is cluster and the unique identifier is the cluster name. Example: cluster:my-db-cluster.   Amazon SageMaker endpoint variant - The resource type is variant and the unique identifier is the resource ID. Example: endpoint/my-end-point/variant/KMeansClustering.   Custom resources are not supported with a resource type. This parameter must specify the OutputValue from the CloudFormation template stack used to access the resources. The unique identifier is defined by the service provider. More information is available in our GitHub repository.   Amazon Comprehend document classification endpoint - The resource type and unique identifier are specified using the endpoint ARN. Example: arn:aws:comprehend:us-west-2:123456789012:document-classifier-endpoint/EXAMPLE.   Amazon Comprehend entity recognizer endpoint - The resource type and unique identifier are specified using the endpoint ARN. Example: arn:aws:comprehend:us-west-2:123456789012:entity-recognizer-endpoint/EXAMPLE.   Lambda provisioned concurrency - The resource type is function and the unique identifier is the function name with a function version or alias name suffix that is not $LATEST. Example: function:my-function:prod or function:my-function:1.   Amazon Keyspaces table - The resource type is table and the unique identifier is the table name. Example: keyspace/mykeyspace/table/mytable.   Amazon MSK cluster - The resource type and unique identifier are specified using the cluster ARN. Example: arn:aws:kafka:us-east-1:123456789012:cluster/demo-cluster-1/6357e0b2-0e6a-4b86-a0b4-70df934c2e31-5.  . Defaults to None.
        scalable_dimension(str, optional): The scalable dimension. This string consists of the service namespace, resource type, and scaling property. If you specify a scalable dimension, you must also specify a resource ID.    ecs:service:DesiredCount - The desired task count of an ECS service.    ec2:spot-fleet-request:TargetCapacity - The target capacity of a Spot Fleet request.    elasticmapreduce:instancegroup:InstanceCount - The instance count of an EMR Instance Group.    appstream:fleet:DesiredCapacity - The desired capacity of an AppStream 2.0 fleet.    dynamodb:table:ReadCapacityUnits - The provisioned read capacity for a DynamoDB table.    dynamodb:table:WriteCapacityUnits - The provisioned write capacity for a DynamoDB table.    dynamodb:index:ReadCapacityUnits - The provisioned read capacity for a DynamoDB global secondary index.    dynamodb:index:WriteCapacityUnits - The provisioned write capacity for a DynamoDB global secondary index.    rds:cluster:ReadReplicaCount - The count of Aurora Replicas in an Aurora DB cluster. Available for Aurora MySQL-compatible edition and Aurora PostgreSQL-compatible edition.    sagemaker:variant:DesiredInstanceCount - The number of EC2 instances for an Amazon SageMaker model endpoint variant.    custom-resource:ResourceType:Property - The scalable dimension for a custom resource provided by your own application or service.    comprehend:document-classifier-endpoint:DesiredInferenceUnits - The number of inference units for an Amazon Comprehend document classification endpoint.    comprehend:entity-recognizer-endpoint:DesiredInferenceUnits - The number of inference units for an Amazon Comprehend entity recognizer endpoint.    lambda:function:ProvisionedConcurrency - The provisioned concurrency for a Lambda function.    cassandra:table:ReadCapacityUnits - The provisioned read capacity for an Amazon Keyspaces table.    cassandra:table:WriteCapacityUnits - The provisioned write capacity for an Amazon Keyspaces table.    kafka:broker-storage:VolumeSize - The provisioned volume size (in GiB) for brokers in an Amazon MSK cluster.  . Defaults to None.
        max_results(int, optional): The maximum number of scheduled action results. This value can be between 1 and 50. The default value is 50. If this parameter is used, the operation returns up to MaxResults results at a time, along with a NextToken value. To get the next set of results, include the NextToken value in a subsequent call. If this parameter is not used, the operation returns up to 50 results and a NextToken value, if applicable. Defaults to None.
        next_token(str, optional): The token for the next set of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.application_autoscaling.scheduled_action.describe_all(
                ctx, service_namespace=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.application_autoscaling.scheduled_action.describe_all service_namespace=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="application-autoscaling",
        operation="describe_scheduled_actions",
        op_kwargs={
            "ScheduledActionNames": scheduled_action_names,
            "ServiceNamespace": service_namespace,
            "ResourceId": resource_id,
            "ScalableDimension": scalable_dimension,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def put(
    hub,
    ctx,
    service_namespace: str,
    scheduled_action_name: str,
    resource_id: str,
    scalable_dimension: str,
    schedule: str = None,
    timezone: str = None,
    start_time: str = None,
    end_time: str = None,
    scalable_target_action: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates or updates a scheduled action for an Application Auto Scaling scalable target.  Each scalable target is identified by a service namespace, resource ID, and scalable dimension. A scheduled action applies to the scalable target identified by those three attributes. You cannot create a scheduled action until you have registered the resource as a scalable target. When start and end times are specified with a recurring schedule using a cron expression or rates, they form the boundaries for when the recurring action starts and stops. To update a scheduled action, specify the parameters that you want to change. If you don't specify start and end times, the old values are deleted. For more information, see Scheduled scaling in the Application Auto Scaling User Guide.  If a scalable target is deregistered, the scalable target is no longer available to run scheduled actions. Any scheduled actions that were specified for the scalable target are deleted.

    Args:
        service_namespace(str): The namespace of the AWS service that provides the resource. For a resource provided by your own application or service, use custom-resource instead.
        schedule(str, optional): The schedule for this action. The following formats are supported:   At expressions - "at(yyyy-mm-ddThh:mm:ss)"   Rate expressions - "rate(value unit)"   Cron expressions - "cron(fields)"   At expressions are useful for one-time schedules. Cron expressions are useful for scheduled actions that run periodically at a specified date and time, and rate expressions are useful for scheduled actions that run at a regular interval. At and cron expressions use Universal Coordinated Time (UTC) by default. The cron format consists of six fields separated by white spaces: [Minutes] [Hours] [Day_of_Month] [Month] [Day_of_Week] [Year]. For rate expressions, value is a positive integer and unit is minute | minutes | hour | hours | day | days. For more information and examples, see Example scheduled actions for Application Auto Scaling in the Application Auto Scaling User Guide. Defaults to None.
        timezone(str, optional): Specifies the time zone used when setting a scheduled action by using an at or cron expression. If a time zone is not provided, UTC is used by default. Valid values are the canonical names of the IANA time zones supported by Joda-Time (such as Etc/GMT+9 or Pacific/Tahiti). For more information, see https://www.joda.org/joda-time/timezones.html. Defaults to None.
        scheduled_action_name(str): The name of the scheduled action. This name must be unique among all other scheduled actions on the specified scalable target. .
        resource_id(str): The identifier of the resource associated with the scheduled action. This string consists of the resource type and unique identifier.   ECS service - The resource type is service and the unique identifier is the cluster name and service name. Example: service/default/sample-webapp.   Spot Fleet request - The resource type is spot-fleet-request and the unique identifier is the Spot Fleet request ID. Example: spot-fleet-request/sfr-73fbd2ce-aa30-494c-8788-1cee4EXAMPLE.   EMR cluster - The resource type is instancegroup and the unique identifier is the cluster ID and instance group ID. Example: instancegroup/j-2EEZNYKUA1NTV/ig-1791Y4E1L8YI0.   AppStream 2.0 fleet - The resource type is fleet and the unique identifier is the fleet name. Example: fleet/sample-fleet.   DynamoDB table - The resource type is table and the unique identifier is the table name. Example: table/my-table.   DynamoDB global secondary index - The resource type is index and the unique identifier is the index name. Example: table/my-table/index/my-table-index.   Aurora DB cluster - The resource type is cluster and the unique identifier is the cluster name. Example: cluster:my-db-cluster.   Amazon SageMaker endpoint variant - The resource type is variant and the unique identifier is the resource ID. Example: endpoint/my-end-point/variant/KMeansClustering.   Custom resources are not supported with a resource type. This parameter must specify the OutputValue from the CloudFormation template stack used to access the resources. The unique identifier is defined by the service provider. More information is available in our GitHub repository.   Amazon Comprehend document classification endpoint - The resource type and unique identifier are specified using the endpoint ARN. Example: arn:aws:comprehend:us-west-2:123456789012:document-classifier-endpoint/EXAMPLE.   Amazon Comprehend entity recognizer endpoint - The resource type and unique identifier are specified using the endpoint ARN. Example: arn:aws:comprehend:us-west-2:123456789012:entity-recognizer-endpoint/EXAMPLE.   Lambda provisioned concurrency - The resource type is function and the unique identifier is the function name with a function version or alias name suffix that is not $LATEST. Example: function:my-function:prod or function:my-function:1.   Amazon Keyspaces table - The resource type is table and the unique identifier is the table name. Example: keyspace/mykeyspace/table/mytable.   Amazon MSK cluster - The resource type and unique identifier are specified using the cluster ARN. Example: arn:aws:kafka:us-east-1:123456789012:cluster/demo-cluster-1/6357e0b2-0e6a-4b86-a0b4-70df934c2e31-5.  .
        scalable_dimension(str): The scalable dimension. This string consists of the service namespace, resource type, and scaling property.    ecs:service:DesiredCount - The desired task count of an ECS service.    ec2:spot-fleet-request:TargetCapacity - The target capacity of a Spot Fleet request.    elasticmapreduce:instancegroup:InstanceCount - The instance count of an EMR Instance Group.    appstream:fleet:DesiredCapacity - The desired capacity of an AppStream 2.0 fleet.    dynamodb:table:ReadCapacityUnits - The provisioned read capacity for a DynamoDB table.    dynamodb:table:WriteCapacityUnits - The provisioned write capacity for a DynamoDB table.    dynamodb:index:ReadCapacityUnits - The provisioned read capacity for a DynamoDB global secondary index.    dynamodb:index:WriteCapacityUnits - The provisioned write capacity for a DynamoDB global secondary index.    rds:cluster:ReadReplicaCount - The count of Aurora Replicas in an Aurora DB cluster. Available for Aurora MySQL-compatible edition and Aurora PostgreSQL-compatible edition.    sagemaker:variant:DesiredInstanceCount - The number of EC2 instances for an Amazon SageMaker model endpoint variant.    custom-resource:ResourceType:Property - The scalable dimension for a custom resource provided by your own application or service.    comprehend:document-classifier-endpoint:DesiredInferenceUnits - The number of inference units for an Amazon Comprehend document classification endpoint.    comprehend:entity-recognizer-endpoint:DesiredInferenceUnits - The number of inference units for an Amazon Comprehend entity recognizer endpoint.    lambda:function:ProvisionedConcurrency - The provisioned concurrency for a Lambda function.    cassandra:table:ReadCapacityUnits - The provisioned read capacity for an Amazon Keyspaces table.    cassandra:table:WriteCapacityUnits - The provisioned write capacity for an Amazon Keyspaces table.    kafka:broker-storage:VolumeSize - The provisioned volume size (in GiB) for brokers in an Amazon MSK cluster.  .
        start_time(str, optional): The date and time for this scheduled action to start, in UTC. Defaults to None.
        end_time(str, optional): The date and time for the recurring schedule to end, in UTC. Defaults to None.
        scalable_target_action(Dict, optional): The new minimum and maximum capacity. You can set both values or just one. At the scheduled time, if the current capacity is below the minimum capacity, Application Auto Scaling scales out to the minimum capacity. If the current capacity is above the maximum capacity, Application Auto Scaling scales in to the maximum capacity. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.application_autoscaling.scheduled_action.put(
                ctx,
                service_namespace=value,
                scheduled_action_name=value,
                resource_id=value,
                scalable_dimension=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.application_autoscaling.scheduled_action.put service_namespace=value, scheduled_action_name=value, resource_id=value, scalable_dimension=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="application-autoscaling",
        operation="put_scheduled_action",
        op_kwargs={
            "ServiceNamespace": service_namespace,
            "Schedule": schedule,
            "Timezone": timezone,
            "ScheduledActionName": scheduled_action_name,
            "ResourceId": resource_id,
            "ScalableDimension": scalable_dimension,
            "StartTime": start_time,
            "EndTime": end_time,
            "ScalableTargetAction": scalable_target_action,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def associate(
    hub, ctx, server_name: str, node_name: str, engine_attributes: List
) -> Dict:
    r"""
    **Autogenerated function**

     Associates a new node with the server. For more information about how to disassociate a node, see DisassociateNode.  On a Chef server: This command is an alternative to knife bootstrap.  Example (Chef): aws opsworks-cm associate-node --server-name MyServer --node-name MyManagedNode --engine-attributes "Name=CHEF_ORGANIZATION,Value=default" "Name=CHEF_NODE_PUBLIC_KEY,Value=public-key-pem"   On a Puppet server, this command is an alternative to the puppet cert sign command that signs a Puppet node CSR.   Example (Puppet): aws opsworks-cm associate-node --server-name MyServer --node-name MyManagedNode --engine-attributes "Name=PUPPET_NODE_CSR,Value=csr-pem"   A node can can only be associated with servers that are in a HEALTHY state. Otherwise, an InvalidStateException is thrown. A ResourceNotFoundException is thrown when the server does not exist. A ValidationException is raised when parameters of the request are not valid. The AssociateNode API call can be integrated into Auto Scaling configurations, AWS Cloudformation templates, or the user data of a server's instance.

    Args:
        server_name(str): The name of the server with which to associate the node. .
        node_name(str): The name of the node. .
        engine_attributes(List): Engine attributes used for associating the node.   Attributes accepted in a AssociateNode request for Chef     CHEF_ORGANIZATION: The Chef organization with which the node is associated. By default only one organization named default can exist.     CHEF_NODE_PUBLIC_KEY: A PEM-formatted public key. This key is required for the chef-client agent to access the Chef API.     Attributes accepted in a AssociateNode request for Puppet     PUPPET_NODE_CSR: A PEM-formatted certificate-signing request (CSR) that is created by the node.   .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opsworkscm.node.init.associate(
                ctx, server_name=value, node_name=value, engine_attributes=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opsworkscm.node.init.associate server_name=value, node_name=value, engine_attributes=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworkscm",
        operation="associate_node",
        op_kwargs={
            "ServerName": server_name,
            "NodeName": node_name,
            "EngineAttributes": engine_attributes,
        },
    )


async def disassociate(
    hub, ctx, server_name: str, node_name: str, engine_attributes: List = None
) -> Dict:
    r"""
    **Autogenerated function**

     Disassociates a node from an AWS OpsWorks CM server, and removes the node from the server's managed nodes. After a node is disassociated, the node key pair is no longer valid for accessing the configuration manager's API. For more information about how to associate a node, see AssociateNode.  A node can can only be disassociated from a server that is in a HEALTHY state. Otherwise, an InvalidStateException is thrown. A ResourceNotFoundException is thrown when the server does not exist. A ValidationException is raised when parameters of the request are not valid.

    Args:
        server_name(str): The name of the server from which to disassociate the node. .
        node_name(str): The name of the client node. .
        engine_attributes(List, optional): Engine attributes that are used for disassociating the node. No attributes are required for Puppet.   Attributes required in a DisassociateNode request for Chef     CHEF_ORGANIZATION: The Chef organization with which the node was associated. By default only one organization named default can exist.   . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opsworkscm.node.init.disassociate(
                ctx, server_name=value, node_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opsworkscm.node.init.disassociate server_name=value, node_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworkscm",
        operation="disassociate_node",
        op_kwargs={
            "ServerName": server_name,
            "NodeName": node_name,
            "EngineAttributes": engine_attributes,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, project_arn: str, name: str, type_: str, content_type: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Uploads an app or test scripts.

    Args:
        project_arn(str): The ARN of the project for the upload.
        name(str): The upload's file name. The name should not contain any forward slashes (/). If you are uploading an iOS app, the file name must end with the .ipa extension. If you are uploading an Android app, the file name must end with the .apk extension. For all others, the file name must end with the .zip file extension.
        type_(str): The upload's upload type. Must be one of the following values:   ANDROID_APP   IOS_APP   WEB_APP   EXTERNAL_DATA   APPIUM_JAVA_JUNIT_TEST_PACKAGE   APPIUM_JAVA_TESTNG_TEST_PACKAGE   APPIUM_PYTHON_TEST_PACKAGE   APPIUM_NODE_TEST_PACKAGE   APPIUM_RUBY_TEST_PACKAGE   APPIUM_WEB_JAVA_JUNIT_TEST_PACKAGE   APPIUM_WEB_JAVA_TESTNG_TEST_PACKAGE   APPIUM_WEB_PYTHON_TEST_PACKAGE   APPIUM_WEB_NODE_TEST_PACKAGE   APPIUM_WEB_RUBY_TEST_PACKAGE   CALABASH_TEST_PACKAGE   INSTRUMENTATION_TEST_PACKAGE   UIAUTOMATION_TEST_PACKAGE   UIAUTOMATOR_TEST_PACKAGE   XCTEST_TEST_PACKAGE   XCTEST_UI_TEST_PACKAGE   APPIUM_JAVA_JUNIT_TEST_SPEC   APPIUM_JAVA_TESTNG_TEST_SPEC   APPIUM_PYTHON_TEST_SPEC   APPIUM_NODE_TEST_SPEC   APPIUM_RUBY_TEST_SPEC   APPIUM_WEB_JAVA_JUNIT_TEST_SPEC   APPIUM_WEB_JAVA_TESTNG_TEST_SPEC   APPIUM_WEB_PYTHON_TEST_SPEC   APPIUM_WEB_NODE_TEST_SPEC   APPIUM_WEB_RUBY_TEST_SPEC   INSTRUMENTATION_TEST_SPEC   XCTEST_UI_TEST_SPEC    If you call CreateUpload with WEB_APP specified, AWS Device Farm throws an ArgumentException error.
        content_type(str, optional): The upload's content type (for example, application/octet-stream). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.upload.create(
                ctx, project_arn=value, name=value, type_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.upload.create project_arn=value, name=value, type_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devicefarm",
        operation="create_upload",
        op_kwargs={
            "projectArn": project_arn,
            "name": name,
            "type": type_,
            "contentType": content_type,
        },
    )


async def delete(hub, ctx, arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an upload given the upload ARN.

    Args:
        arn(str): Represents the Amazon Resource Name (ARN) of the Device Farm upload to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.upload.delete(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.upload.delete arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devicefarm",
        operation="delete_upload",
        op_kwargs={"arn": arn},
    )


async def get(hub, ctx, arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about an upload.

    Args:
        arn(str): The upload's ARN.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.upload.get(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.upload.get arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="devicefarm", operation="get_upload", op_kwargs={"arn": arn}
    )


async def list_all(
    hub, ctx, arn: str, type_: str = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about uploads, given an AWS Device Farm project ARN.

    Args:
        arn(str): The Amazon Resource Name (ARN) of the project for which you want to list uploads.
        type_(str, optional): The type of upload. Must be one of the following values:   ANDROID_APP   IOS_APP   WEB_APP   EXTERNAL_DATA   APPIUM_JAVA_JUNIT_TEST_PACKAGE   APPIUM_JAVA_TESTNG_TEST_PACKAGE   APPIUM_PYTHON_TEST_PACKAGE   APPIUM_NODE_TEST_PACKAGE   APPIUM_RUBY_TEST_PACKAGE   APPIUM_WEB_JAVA_JUNIT_TEST_PACKAGE   APPIUM_WEB_JAVA_TESTNG_TEST_PACKAGE   APPIUM_WEB_PYTHON_TEST_PACKAGE   APPIUM_WEB_NODE_TEST_PACKAGE   APPIUM_WEB_RUBY_TEST_PACKAGE   CALABASH_TEST_PACKAGE   INSTRUMENTATION_TEST_PACKAGE   UIAUTOMATION_TEST_PACKAGE   UIAUTOMATOR_TEST_PACKAGE   XCTEST_TEST_PACKAGE   XCTEST_UI_TEST_PACKAGE   APPIUM_JAVA_JUNIT_TEST_SPEC   APPIUM_JAVA_TESTNG_TEST_SPEC   APPIUM_PYTHON_TEST_SPEC   APPIUM_NODE_TEST_SPEC    APPIUM_RUBY_TEST_SPEC   APPIUM_WEB_JAVA_JUNIT_TEST_SPEC   APPIUM_WEB_JAVA_TESTNG_TEST_SPEC   APPIUM_WEB_PYTHON_TEST_SPEC   APPIUM_WEB_NODE_TEST_SPEC   APPIUM_WEB_RUBY_TEST_SPEC   INSTRUMENTATION_TEST_SPEC   XCTEST_UI_TEST_SPEC  . Defaults to None.
        next_token(str, optional): An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.upload.list_all(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.upload.list_all arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devicefarm",
        operation="list_uploads",
        op_kwargs={"arn": arn, "type": type_, "nextToken": next_token},
    )


async def update(
    hub,
    ctx,
    arn: str,
    name: str = None,
    content_type: str = None,
    edit_content: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an uploaded test spec.

    Args:
        arn(str): The Amazon Resource Name (ARN) of the uploaded test spec.
        name(str, optional): The upload's test spec file name. The name must not contain any forward slashes (/). The test spec file name must end with the .yaml or .yml file extension. Defaults to None.
        content_type(str, optional): The upload's content type (for example, application/x-yaml). Defaults to None.
        edit_content(bool, optional): Set to true if the YAML file has changed and must be updated. Otherwise, set to false. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.upload.update(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.upload.update arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devicefarm",
        operation="update_upload",
        op_kwargs={
            "arn": arn,
            "name": name,
            "contentType": content_type,
            "editContent": edit_content,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "creation_property"


async def modify(
    hub, ctx, resource_id: str, workspace_creation_properties: Dict
) -> Dict:
    r"""
    **Autogenerated function**

    Modify the default properties used to create WorkSpaces.

    Args:
        resource_id(str): The identifier of the directory.
        workspace_creation_properties(Dict): The default properties for creating WorkSpaces.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workspace.workspace.creation_property_.modify(
                ctx, resource_id=value, workspace_creation_properties=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workspace.workspace.creation_property.modify resource_id=value, workspace_creation_properties=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workspaces",
        operation="modify_workspace_creation_properties",
        op_kwargs={
            "ResourceId": resource_id,
            "WorkspaceCreationProperties": workspace_creation_properties,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    stream_name: str,
    device_name: str = None,
    media_type: str = None,
    kms_key_id: str = None,
    data_retention_in_hours: int = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new Kinesis video stream.  When you create a new stream, Kinesis Video Streams assigns it a version number. When you change the stream's metadata, Kinesis Video Streams updates the version.   CreateStream is an asynchronous operation. For information about how the service works, see How it Works.  You must have permissions for the KinesisVideo:CreateStream action.

    Args:
        device_name(str, optional): The name of the device that is writing to the stream.   In the current implementation, Kinesis Video Streams does not use this name. . Defaults to None.
        stream_name(str): A name for the stream that you are creating. The stream name is an identifier for the stream, and must be unique for each account and region.
        media_type(str, optional): The media type of the stream. Consumers of the stream can use this information when processing the stream. For more information about media types, see Media Types. If you choose to specify the MediaType, see Naming Requirements for guidelines. Example valid values include "video/h264" and "video/h264,audio/aac". This parameter is optional; the default value is null (or empty in JSON). Defaults to None.
        kms_key_id(str, optional): The ID of the AWS Key Management Service (AWS KMS) key that you want Kinesis Video Streams to use to encrypt stream data. If no key ID is specified, the default, Kinesis Video-managed key (aws/kinesisvideo) is used.  For more information, see DescribeKey. . Defaults to None.
        data_retention_in_hours(int, optional): The number of hours that you want to retain the data in the stream. Kinesis Video Streams retains the data in a data store that is associated with the stream. The default value is 0, indicating that the stream does not persist data. When the DataRetentionInHours value is 0, consumers can still consume the fragments that remain in the service host buffer, which has a retention time limit of 5 minutes and a retention memory limit of 200 MB. Fragments are removed from the buffer when either limit is reached. Defaults to None.
        tags(Dict, optional): A list of tags to associate with the specified stream. Each tag is a key-value pair (the value is optional). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisvideo.stream.create(ctx, stream_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisvideo.stream.create stream_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisvideo",
        operation="create_stream",
        op_kwargs={
            "DeviceName": device_name,
            "StreamName": stream_name,
            "MediaType": media_type,
            "KmsKeyId": kms_key_id,
            "DataRetentionInHours": data_retention_in_hours,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, stream_arn: str, current_version: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a Kinesis video stream and the data contained in the stream.  This method marks the stream for deletion, and makes the data in the stream inaccessible immediately.    To ensure that you have the latest version of the stream before deleting it, you can specify the stream version. Kinesis Video Streams assigns a version to each stream. When you update a stream, Kinesis Video Streams assigns a new version number. To get the latest stream version, use the DescribeStream API.  This operation requires permission for the KinesisVideo:DeleteStream action.

    Args:
        stream_arn(str): The Amazon Resource Name (ARN) of the stream that you want to delete. .
        current_version(str, optional): Optional: The version of the stream that you want to delete.  Specify the version as a safeguard to ensure that your are deleting the correct stream. To get the stream version, use the DescribeStream API. If not specified, only the CreationTime is checked before deleting the stream. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisvideo.stream.delete(ctx, stream_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisvideo.stream.delete stream_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisvideo",
        operation="delete_stream",
        op_kwargs={"StreamARN": stream_arn, "CurrentVersion": current_version},
    )


async def describe(hub, ctx, stream_name: str = None, stream_arn: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns the most current information about the specified stream. You must specify either the StreamName or the StreamARN.

    Args:
        stream_name(str, optional): The name of the stream. Defaults to None.
        stream_arn(str, optional): The Amazon Resource Name (ARN) of the stream. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisvideo.stream.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisvideo.stream.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisvideo",
        operation="describe_stream",
        op_kwargs={"StreamName": stream_name, "StreamARN": stream_arn},
    )


async def list_all(
    hub,
    ctx,
    max_results: int = None,
    next_token: str = None,
    stream_name_condition: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns an array of StreamInfo objects. Each object describes a stream. To retrieve only streams that satisfy a specific condition, you can specify a StreamNameCondition.

    Args:
        max_results(int, optional): The maximum number of streams to return in the response. The default is 10,000. Defaults to None.
        next_token(str, optional): If you specify this parameter, when the result of a ListStreams operation is truncated, the call returns the NextToken in the response. To get another batch of streams, provide this token in your next request. Defaults to None.
        stream_name_condition(Dict, optional): Optional: Returns only streams that satisfy a specific condition. Currently, you can specify only the prefix of a stream name as a condition. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisvideo.stream.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisvideo.stream.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisvideo",
        operation="list_streams",
        op_kwargs={
            "MaxResults": max_results,
            "NextToken": next_token,
            "StreamNameCondition": stream_name_condition,
        },
    )


async def tag(
    hub, ctx, tags: Dict, stream_arn: str = None, stream_name: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Adds one or more tags to a stream. A tag is a key-value pair (the value is optional) that you can define and assign to AWS resources. If you specify a tag that already exists, the tag value is replaced with the value that you specify in the request. For more information, see Using Cost Allocation Tags in the AWS Billing and Cost Management User Guide.  You must provide either the StreamName or the StreamARN. This operation requires permission for the KinesisVideo:TagStream action. Kinesis video streams support up to 50 tags.

    Args:
        stream_arn(str, optional): The Amazon Resource Name (ARN) of the resource that you want to add the tag or tags to. Defaults to None.
        stream_name(str, optional): The name of the stream that you want to add the tag or tags to. Defaults to None.
        tags(Dict): A list of tags to associate with the specified stream. Each tag is a key-value pair (the value is optional).

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisvideo.stream.tag(ctx, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisvideo.stream.tag tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisvideo",
        operation="tag_stream",
        op_kwargs={"StreamARN": stream_arn, "StreamName": stream_name, "Tags": tags},
    )


async def untag(
    hub, ctx, tag_key_list: List, stream_arn: str = None, stream_name: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Removes one or more tags from a stream. In the request, specify only a tag key or keys; don't specify the value. If you specify a tag key that does not exist, it's ignored. In the request, you must provide the StreamName or StreamARN.

    Args:
        stream_arn(str, optional): The Amazon Resource Name (ARN) of the stream that you want to remove tags from. Defaults to None.
        stream_name(str, optional): The name of the stream that you want to remove tags from. Defaults to None.
        tag_key_list(List): A list of the keys of the tags that you want to remove.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisvideo.stream.untag(ctx, tag_key_list=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisvideo.stream.untag tag_key_list=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisvideo",
        operation="untag_stream",
        op_kwargs={
            "StreamARN": stream_arn,
            "StreamName": stream_name,
            "TagKeyList": tag_key_list,
        },
    )


async def update(
    hub,
    ctx,
    current_version: str,
    stream_name: str = None,
    stream_arn: str = None,
    device_name: str = None,
    media_type: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates stream metadata, such as the device name and media type. You must provide the stream name or the Amazon Resource Name (ARN) of the stream. To make sure that you have the latest version of the stream before updating it, you can specify the stream version. Kinesis Video Streams assigns a version to each stream. When you update a stream, Kinesis Video Streams assigns a new version number. To get the latest stream version, use the DescribeStream API.   UpdateStream is an asynchronous operation, and takes time to complete.

    Args:
        stream_name(str, optional): The name of the stream whose metadata you want to update. The stream name is an identifier for the stream, and must be unique for each account and region. Defaults to None.
        stream_arn(str, optional): The ARN of the stream whose metadata you want to update. Defaults to None.
        current_version(str): The version of the stream whose metadata you want to update.
        device_name(str, optional): The name of the device that is writing to the stream.    In the current implementation, Kinesis Video Streams does not use this name.  . Defaults to None.
        media_type(str, optional): The stream's media type. Use MediaType to specify the type of content that the stream contains to the consumers of the stream. For more information about media types, see Media Types. If you choose to specify the MediaType, see Naming Requirements. To play video on the console, you must specify the correct video type. For example, if the video in the stream is H.264, specify video/h264 as the MediaType. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisvideo.stream.update(ctx, current_version=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisvideo.stream.update current_version=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisvideo",
        operation="update_stream",
        op_kwargs={
            "StreamName": stream_name,
            "StreamARN": stream_arn,
            "CurrentVersion": current_version,
            "DeviceName": device_name,
            "MediaType": media_type,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get_all(
    hub,
    ctx,
    association_type: str,
    resource_share_arns: List = None,
    resource_arn: str = None,
    principal: str = None,
    association_status: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets the resources or principals for the resource shares that you own.

    Args:
        association_type(str): The association type. Specify PRINCIPAL to list the principals that are associated with the specified resource share. Specify RESOURCE to list the resources that are associated with the specified resource share.
        resource_share_arns(List, optional): The Amazon Resource Names (ARN) of the resource shares. Defaults to None.
        resource_arn(str, optional): The Amazon Resource Name (ARN) of the resource. You cannot specify this parameter if the association type is PRINCIPAL. Defaults to None.
        principal(str, optional): The principal. You cannot specify this parameter if the association type is RESOURCE. Defaults to None.
        association_status(str, optional): The association status. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ram.resource.share.association.get_all(
                ctx, association_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ram.resource.share.association.get_all association_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ram",
        operation="get_resource_share_associations",
        op_kwargs={
            "associationType": association_type,
            "resourceShareArns": resource_share_arns,
            "resourceArn": resource_arn,
            "principal": principal,
            "associationStatus": association_status,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def put_multiple(hub, ctx, entries: List) -> Dict:
    r"""
    **Autogenerated function**

    This is used by SaaS partners to write events to a customer's partner event bus. AWS customers do not use this operation.

    Args:
        entries(List): The list of events to write to the event bus.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.event.partner_event.init.put_multiple(ctx, entries=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.event.partner_event.init.put_multiple entries=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="events",
        operation="put_partner_events",
        op_kwargs={"Entries": entries},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    description: str = None,
    display_name: str = None,
    storage_connectors: List = None,
    redirect_url: str = None,
    feedback_url: str = None,
    user_settings: List = None,
    application_settings: Dict = None,
    tags: Dict = None,
    access_endpoints: List = None,
    embed_host_domains: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a stack to start streaming applications to users. A stack consists of an associated fleet, user access policies, and storage configurations.

    Args:
        name(str): The name of the stack.
        description(str, optional): The description to display. Defaults to None.
        display_name(str, optional): The stack name to display. Defaults to None.
        storage_connectors(List, optional): The storage connectors to enable. Defaults to None.
        redirect_url(str, optional): The URL that users are redirected to after their streaming session ends. Defaults to None.
        feedback_url(str, optional): The URL that users are redirected to after they click the Send Feedback link. If no URL is specified, no Send Feedback link is displayed. Defaults to None.
        user_settings(List, optional): The actions that are enabled or disabled for users during their streaming sessions. By default, these actions are enabled. . Defaults to None.
        application_settings(Dict, optional): The persistent application settings for users of a stack. When these settings are enabled, changes that users make to applications and Windows settings are automatically saved after each session and applied to the next session. Defaults to None.
        tags(Dict, optional): The tags to associate with the stack. A tag is a key-value pair, and the value is optional. For example, Environment=Test. If you do not specify a value, Environment=.  If you do not specify a value, the value is set to an empty string. Generally allowed characters are: letters, numbers, and spaces representable in UTF-8, and the following special characters:  _ . : / = + \ - @ For more information about tags, see Tagging Your Resources in the Amazon AppStream 2.0 Administration Guide. Defaults to None.
        access_endpoints(List, optional): The list of interface VPC endpoint (interface endpoint) objects. Users of the stack can connect to AppStream 2.0 only through the specified endpoints. Defaults to None.
        embed_host_domains(List, optional): The domains where AppStream 2.0 streaming sessions can be embedded in an iframe. You must approve the domains that you want to host embedded AppStream 2.0 streaming sessions. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appstream.stack.create(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appstream.stack.create name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appstream",
        operation="create_stack",
        op_kwargs={
            "Name": name,
            "Description": description,
            "DisplayName": display_name,
            "StorageConnectors": storage_connectors,
            "RedirectURL": redirect_url,
            "FeedbackURL": feedback_url,
            "UserSettings": user_settings,
            "ApplicationSettings": application_settings,
            "Tags": tags,
            "AccessEndpoints": access_endpoints,
            "EmbedHostDomains": embed_host_domains,
        },
    )


async def delete(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified stack. After the stack is deleted, the application streaming environment provided by the stack is no longer available to users. Also, any reservations made for application streaming sessions for the stack are released.

    Args:
        name(str): The name of the stack.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appstream.stack.delete(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appstream.stack.delete name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appstream",
        operation="delete_stack",
        op_kwargs={"Name": name},
    )


async def describe_all(hub, ctx, names: List = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list that describes one or more specified stacks, if the stack names are provided. Otherwise, all stacks in the account are described.

    Args:
        names(List, optional): The names of the stacks to describe. Defaults to None.
        next_token(str, optional): The pagination token to use to retrieve the next page of results for this operation. If this value is null, it retrieves the first page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appstream.stack.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appstream.stack.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appstream",
        operation="describe_stacks",
        op_kwargs={"Names": names, "NextToken": next_token},
    )


async def update(
    hub,
    ctx,
    name: str,
    display_name: str = None,
    description: str = None,
    storage_connectors: List = None,
    delete_storage_connectors: bool = None,
    redirect_url: str = None,
    feedback_url: str = None,
    attributes_to_delete: List = None,
    user_settings: List = None,
    application_settings: Dict = None,
    access_endpoints: List = None,
    embed_host_domains: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the specified fields for the specified stack.

    Args:
        display_name(str, optional): The stack name to display. Defaults to None.
        description(str, optional): The description to display. Defaults to None.
        name(str): The name of the stack.
        storage_connectors(List, optional): The storage connectors to enable. Defaults to None.
        delete_storage_connectors(bool, optional): Deletes the storage connectors currently enabled for the stack. Defaults to None.
        redirect_url(str, optional): The URL that users are redirected to after their streaming session ends. Defaults to None.
        feedback_url(str, optional): The URL that users are redirected to after they choose the Send Feedback link. If no URL is specified, no Send Feedback link is displayed. Defaults to None.
        attributes_to_delete(List, optional): The stack attributes to delete. Defaults to None.
        user_settings(List, optional): The actions that are enabled or disabled for users during their streaming sessions. By default, these actions are enabled. Defaults to None.
        application_settings(Dict, optional): The persistent application settings for users of a stack. When these settings are enabled, changes that users make to applications and Windows settings are automatically saved after each session and applied to the next session. Defaults to None.
        access_endpoints(List, optional): The list of interface VPC endpoint (interface endpoint) objects. Users of the stack can connect to AppStream 2.0 only through the specified endpoints. Defaults to None.
        embed_host_domains(List, optional): The domains where AppStream 2.0 streaming sessions can be embedded in an iframe. You must approve the domains that you want to host embedded AppStream 2.0 streaming sessions. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appstream.stack.update(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appstream.stack.update name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appstream",
        operation="update_stack",
        op_kwargs={
            "DisplayName": display_name,
            "Description": description,
            "Name": name,
            "StorageConnectors": storage_connectors,
            "DeleteStorageConnectors": delete_storage_connectors,
            "RedirectURL": redirect_url,
            "FeedbackURL": feedback_url,
            "AttributesToDelete": attributes_to_delete,
            "UserSettings": user_settings,
            "ApplicationSettings": application_settings,
            "AccessEndpoints": access_endpoints,
            "EmbedHostDomains": embed_host_domains,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Lists all of the DMS attributes for a customer account. These attributes include DMS quotas for the account and a unique account identifier in a particular DMS region. DMS quotas include a list of resource quotas supported by the account, such as the number of replication instances allowed. The description for each resource quota, includes the quota name, current usage toward that quota, and the quota's maximum value. DMS uses the unique account identifier to name each artifact used by DMS in the given region. This command does not take any parameters.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dms.account_attribute.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dms.account_attribute.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="dms", operation="describe_account_attributes", op_kwargs={}
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(hub, ctx, protocol: str, contact_endpoint: str) -> Dict:
    r"""
    **Autogenerated function**

    Creates an email or SMS text message contact method. A contact method is used to send you notifications about your Amazon Lightsail resources. You can add one email address and one mobile phone number contact method in each AWS Region. However, SMS text messaging is not supported in some AWS Regions, and SMS text messages cannot be sent to some countries/regions. For more information, see Notifications in Amazon Lightsail.

    Args:
        protocol(str): The protocol of the contact method, such as Email or SMS (text messaging). The SMS protocol is supported only in the following AWS Regions.   US East (N. Virginia) (us-east-1)   US West (Oregon) (us-west-2)   Europe (Ireland) (eu-west-1)   Asia Pacific (Tokyo) (ap-northeast-1)   Asia Pacific (Singapore) (ap-southeast-1)   Asia Pacific (Sydney) (ap-southeast-2)   For a list of countries/regions where SMS text messages can be sent, and the latest AWS Regions where SMS text messaging is supported, see Supported Regions and Countries in the Amazon SNS Developer Guide. For more information about notifications in Amazon Lightsail, see Notifications in Amazon Lightsail.
        contact_endpoint(str): The destination of the contact method, such as an email address or a mobile phone number. Use the E.164 format when specifying a mobile phone number. E.164 is a standard for the phone number structure used for international telecommunication. Phone numbers that follow this format can have a maximum of 15 digits, and they are prefixed with the plus character (+) and the country code. For example, a U.S. phone number in E.164 format would be specified as +1XXX5550100. For more information, see E.164 on Wikipedia.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.contact_method.init.create(
                ctx, protocol=value, contact_endpoint=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.contact_method.init.create protocol=value, contact_endpoint=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="create_contact_method",
        op_kwargs={"protocol": protocol, "contactEndpoint": contact_endpoint},
    )


async def delete(hub, ctx, protocol: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a contact method. A contact method is used to send you notifications about your Amazon Lightsail resources. You can add one email address and one mobile phone number contact method in each AWS Region. However, SMS text messaging is not supported in some AWS Regions, and SMS text messages cannot be sent to some countries/regions. For more information, see Notifications in Amazon Lightsail.

    Args:
        protocol(str): The protocol that will be deleted, such as Email or SMS (text messaging).  To delete an Email and an SMS contact method if you added both, you must run separate DeleteContactMethod actions to delete each protocol. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.contact_method.init.delete(ctx, protocol=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.contact_method.init.delete protocol=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="delete_contact_method",
        op_kwargs={"protocol": protocol},
    )


async def get_all(hub, ctx, protocols: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about the configured contact methods. Specify a protocol in your request to return information about a specific contact method. A contact method is used to send you notifications about your Amazon Lightsail resources. You can add one email address and one mobile phone number contact method in each AWS Region. However, SMS text messaging is not supported in some AWS Regions, and SMS text messages cannot be sent to some countries/regions. For more information, see Notifications in Amazon Lightsail.

    Args:
        protocols(List, optional): The protocols used to send notifications, such as Email, or SMS (text messaging). Specify a protocol in your request to return information about a specific contact method protocol. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.contact_method.init.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.contact_method.init.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="get_contact_methods",
        op_kwargs={"protocols": protocols},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, application_id: str, semantic_version: str = None) -> Dict:
    r"""
        **Autogenerated function**

        Creates an AWS CloudFormation template.

        Args:
            application_id(str): The Amazon Resource Name (ARN) of the application.
            semantic_version(str, optional): The semantic version of the application:
    https://semver.org/
    . Defaults to None.

        Returns:
            Dict

        Examples:
            Call from code:

            .. code-block:: python

                await hub.exec.aws_auto.serverlessrepo.cloud_formation.template.create(
                    ctx, application_id=value
                )

            Call from CLI:

            .. code-block:: bash

                $ idem exec aws_auto.serverlessrepo.cloud_formation.template.create application_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="serverlessrepo",
        operation="create_cloud_formation_template",
        op_kwargs={
            "ApplicationId": application_id,
            "SemanticVersion": semantic_version,
        },
    )


async def get(hub, ctx, application_id: str, template_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets the specified AWS CloudFormation template.

    Args:
        application_id(str): The Amazon Resource Name (ARN) of the application.
        template_id(str): The UUID returned by CreateCloudFormationTemplate.Pattern: [0-9a-fA-F]{8}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{12}.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.serverlessrepo.cloud_formation.template.get(
                ctx, application_id=value, template_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.serverlessrepo.cloud_formation.template.get application_id=value, template_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="serverlessrepo",
        operation="get_cloud_formation_template",
        op_kwargs={"ApplicationId": application_id, "TemplateId": template_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(
    hub,
    ctx,
    cluster_identifier: str = None,
    account: str = None,
    grantee: bool = None,
    max_records: int = None,
    marker: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes an endpoint authorization.

    Args:
        cluster_identifier(str, optional): The cluster identifier of the cluster to access. Defaults to None.
        account(str, optional): The AAmazon Web Services account ID of either the cluster owner (grantor) or grantee. If Grantee parameter is true, then the Account value is of the grantor. Defaults to None.
        grantee(bool, optional): Indicates whether to check authorization from a grantor or grantee point of view. If true, Amazon Redshift returns endpoint authorizations that you've been granted. If false (default), checks authorization from a grantor point of view. Defaults to None.
        max_records(int, optional): The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a Marker is included in the response so that the remaining results can be retrieved. Defaults to None.
        marker(str, optional): An optional pagination token provided by a previous DescribeEndpointAuthorization request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by the MaxRecords parameter. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.endpoint.authorization.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.endpoint.authorization.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="describe_endpoint_authorization",
        op_kwargs={
            "ClusterIdentifier": cluster_identifier,
            "Account": account,
            "Grantee": grantee,
            "MaxRecords": max_records,
            "Marker": marker,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def request(hub, ctx, domain: str, workflow_id: str, run_id: str = None) -> None:
    r"""
    **Autogenerated function**

    Records a WorkflowExecutionCancelRequested event in the currently running workflow execution identified by the given domain, workflowId, and runId. This logically requests the cancellation of the workflow execution as a whole. It is up to the decider to take appropriate actions when it receives an execution history with this event.  If the runId isn't specified, the WorkflowExecutionCancelRequested event is recorded in the history of the current open workflow execution with the specified workflowId in the domain.   Because this action allows the workflow to properly clean up and gracefully close, it should be used instead of TerminateWorkflowExecution when possible.   Access Control  You can use IAM policies to control this action's access to Amazon SWF resources as follows:   Use a Resource element with the domain name to limit the action to only specified domains.   Use an Action element to allow or deny permission to call this action.   You cannot use an IAM policy to constrain this action's parameters.   If the caller doesn't have sufficient permissions to invoke the action, or the parameter values fall outside the specified constraints, the action fails. The associated event attribute's cause parameter is set to OPERATION_NOT_PERMITTED. For details and example IAM policies, see Using IAM to Manage Access to Amazon SWF Workflows in the Amazon SWF Developer Guide.

    Args:
        domain(str): The name of the domain containing the workflow execution to cancel.
        workflow_id(str): The workflowId of the workflow execution to cancel.
        run_id(str, optional): The runId of the workflow execution to cancel. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.swf.cancel_workflow_execution.request(
                ctx, domain=value, workflow_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.swf.cancel_workflow_execution.request domain=value, workflow_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="swf",
        operation="request_cancel_workflow_execution",
        op_kwargs={"domain": domain, "workflowId": workflow_id, "runId": run_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    request_timeout_seconds: int,
    acceptance_required: bool,
    rule_set_name: str,
    description: str = None,
    game_session_queue_arns: List = None,
    acceptance_timeout_seconds: int = None,
    notification_target: str = None,
    additional_player_count: int = None,
    custom_event_data: str = None,
    game_properties: List = None,
    game_session_data: str = None,
    backfill_mode: str = None,
    flex_match_mode: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Defines a new matchmaking configuration for use with FlexMatch. Whether your are using FlexMatch with GameLift hosting or as a standalone matchmaking service, the matchmaking configuration sets out rules for matching players and forming teams. If you're also using GameLift hosting, it defines how to start game sessions for each match. Your matchmaking system can use multiple configurations to handle different game scenarios. All matchmaking requests (StartMatchmaking or StartMatchBackfill) identify the matchmaking configuration to use and provide player attributes consistent with that configuration.  To create a matchmaking configuration, you must provide the following: configuration name and FlexMatch mode (with or without GameLift hosting); a rule set that specifies how to evaluate players and find acceptable matches; whether player acceptance is required; and the maximum time allowed for a matchmaking attempt. When using FlexMatch with GameLift hosting, you also need to identify the game session queue to use when starting a game session for the match. In addition, you must set up an Amazon Simple Notification Service (SNS) topic to receive matchmaking notifications. Provide the topic ARN in the matchmaking configuration. An alternative method, continuously polling ticket status with DescribeMatchmaking, is only suitable for games in development with low matchmaking usage.  Learn more    Design a FlexMatch matchmaker    Set up FlexMatch event notification   Related actions   CreateMatchmakingConfiguration | DescribeMatchmakingConfigurations | UpdateMatchmakingConfiguration | DeleteMatchmakingConfiguration | CreateMatchmakingRuleSet | DescribeMatchmakingRuleSets | ValidateMatchmakingRuleSet | DeleteMatchmakingRuleSet | All APIs by task

    Args:
        name(str): A unique identifier for the matchmaking configuration. This name is used to identify the configuration associated with a matchmaking request or ticket.
        description(str, optional): A human-readable description of the matchmaking configuration. . Defaults to None.
        game_session_queue_arns(List, optional): The Amazon Resource Name (ARN) that is assigned to a GameLift game session queue resource and uniquely identifies it. ARNs are unique across all Regions. Format is arn:aws:gamelift:<region>::gamesessionqueue/<queue name>. Queues can be located in any Region. Queues are used to start new GameLift-hosted game sessions for matches that are created with this matchmaking configuration. If FlexMatchMode is set to STANDALONE, do not set this parameter. . Defaults to None.
        request_timeout_seconds(int): The maximum duration, in seconds, that a matchmaking ticket can remain in process before timing out. Requests that fail due to timing out can be resubmitted as needed.
        acceptance_timeout_seconds(int, optional): The length of time (in seconds) to wait for players to accept a proposed match, if acceptance is required. . Defaults to None.
        acceptance_required(bool): A flag that determines whether a match that was created with this configuration must be accepted by the matched players. To require acceptance, set to TRUE. With this option enabled, matchmaking tickets use the status REQUIRES_ACCEPTANCE to indicate when a completed potential match is waiting for player acceptance. .
        rule_set_name(str): A unique identifier for the matchmaking rule set to use with this configuration. You can use either the rule set name or ARN value. A matchmaking configuration can only use rule sets that are defined in the same Region.
        notification_target(str, optional): An SNS topic ARN that is set up to receive matchmaking notifications. See  Setting up notifications for matchmaking for more information. Defaults to None.
        additional_player_count(int, optional): The number of player slots in a match to keep open for future players. For example, if the configuration's rule set specifies a match for a single 12-person team, and the additional player count is set to 2, only 10 players are selected for the match. This parameter is not used if FlexMatchMode is set to STANDALONE. Defaults to None.
        custom_event_data(str, optional): Information to be added to all events related to this matchmaking configuration. . Defaults to None.
        game_properties(List, optional): A set of custom properties for a game session, formatted as key:value pairs. These properties are passed to a game server process in the GameSession object with a request to start a new game session (see Start a Game Session). This information is added to the new GameSession object that is created for a successful match. This parameter is not used if FlexMatchMode is set to STANDALONE. Defaults to None.
        game_session_data(str, optional): A set of custom game session properties, formatted as a single string value. This data is passed to a game server process in the GameSession object with a request to start a new game session (see Start a Game Session). This information is added to the new GameSession object that is created for a successful match. This parameter is not used if FlexMatchMode is set to STANDALONE. Defaults to None.
        backfill_mode(str, optional): The method used to backfill game sessions that are created with this matchmaking configuration. Specify MANUAL when your game manages backfill requests manually or does not use the match backfill feature. Specify AUTOMATIC to have GameLift create a StartMatchBackfill request whenever a game session has one or more open slots. Learn more about manual and automatic backfill in  Backfill Existing Games with FlexMatch. Automatic backfill is not available when FlexMatchMode is set to STANDALONE. Defaults to None.
        flex_match_mode(str, optional): Indicates whether this matchmaking configuration is being used with GameLift hosting or as a standalone matchmaking solution.     STANDALONE - FlexMatch forms matches and returns match information, including players and team assignments, in a  MatchmakingSucceeded event.    WITH_QUEUE - FlexMatch forms matches and uses the specified GameLift queue to start a game session for the match.   . Defaults to None.
        tags(List, optional): A list of labels to assign to the new matchmaking configuration resource. Tags are developer-defined key-value pairs. Tagging AWS resources are useful for resource management, access management and cost allocation. For more information, see  Tagging AWS Resources in the AWS General Reference. Once the resource is created, you can use TagResource, UntagResource, and ListTagsForResource to add, remove, and view tags. The maximum tag limit may be lower than stated. See the AWS General Reference for actual tagging limits. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.matchmaking.configuration.create(
                ctx,
                name=value,
                request_timeout_seconds=value,
                acceptance_required=value,
                rule_set_name=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.matchmaking.configuration.create name=value, request_timeout_seconds=value, acceptance_required=value, rule_set_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="create_matchmaking_configuration",
        op_kwargs={
            "Name": name,
            "Description": description,
            "GameSessionQueueArns": game_session_queue_arns,
            "RequestTimeoutSeconds": request_timeout_seconds,
            "AcceptanceTimeoutSeconds": acceptance_timeout_seconds,
            "AcceptanceRequired": acceptance_required,
            "RuleSetName": rule_set_name,
            "NotificationTarget": notification_target,
            "AdditionalPlayerCount": additional_player_count,
            "CustomEventData": custom_event_data,
            "GameProperties": game_properties,
            "GameSessionData": game_session_data,
            "BackfillMode": backfill_mode,
            "FlexMatchMode": flex_match_mode,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Permanently removes a FlexMatch matchmaking configuration. To delete, specify the configuration name. A matchmaking configuration cannot be deleted if it is being used in any active matchmaking tickets.  Related actions   CreateMatchmakingConfiguration | DescribeMatchmakingConfigurations | UpdateMatchmakingConfiguration | DeleteMatchmakingConfiguration | CreateMatchmakingRuleSet | DescribeMatchmakingRuleSets | ValidateMatchmakingRuleSet | DeleteMatchmakingRuleSet | All APIs by task

    Args:
        name(str): A unique identifier for the matchmaking configuration. You can use either the configuration name or ARN value.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.matchmaking.configuration.delete(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.matchmaking.configuration.delete name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="delete_matchmaking_configuration",
        op_kwargs={"Name": name},
    )


async def describe_all(
    hub,
    ctx,
    names: List = None,
    rule_set_name: str = None,
    limit: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the details of FlexMatch matchmaking configurations.  This operation offers the following options: (1) retrieve all matchmaking configurations, (2) retrieve configurations for a specified list, or (3) retrieve all configurations that use a specified rule set name. When requesting multiple items, use the pagination parameters to retrieve results as a set of sequential pages.  If successful, a configuration is returned for each requested name. When specifying a list of names, only configurations that currently exist are returned.   Learn more    Setting up FlexMatch matchmakers   Related actions   CreateMatchmakingConfiguration | DescribeMatchmakingConfigurations | UpdateMatchmakingConfiguration | DeleteMatchmakingConfiguration | CreateMatchmakingRuleSet | DescribeMatchmakingRuleSets | ValidateMatchmakingRuleSet | DeleteMatchmakingRuleSet | All APIs by task

    Args:
        names(List, optional): A unique identifier for the matchmaking configuration(s) to retrieve. You can use either the configuration name or ARN value. To request all existing configurations, leave this parameter empty. Defaults to None.
        rule_set_name(str, optional): A unique identifier for the matchmaking rule set. You can use either the rule set name or ARN value. Use this parameter to retrieve all matchmaking configurations that use this rule set. Defaults to None.
        limit(int, optional): The maximum number of results to return. Use this parameter with NextToken to get results as a set of sequential pages. This parameter is limited to 10. Defaults to None.
        next_token(str, optional): A token that indicates the start of the next sequential page of results. Use the token that is returned with a previous call to this operation. To start at the beginning of the result set, do not specify a value. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.matchmaking.configuration.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.matchmaking.configuration.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="describe_matchmaking_configurations",
        op_kwargs={
            "Names": names,
            "RuleSetName": rule_set_name,
            "Limit": limit,
            "NextToken": next_token,
        },
    )


async def update(
    hub,
    ctx,
    name: str,
    description: str = None,
    game_session_queue_arns: List = None,
    request_timeout_seconds: int = None,
    acceptance_timeout_seconds: int = None,
    acceptance_required: bool = None,
    rule_set_name: str = None,
    notification_target: str = None,
    additional_player_count: int = None,
    custom_event_data: str = None,
    game_properties: List = None,
    game_session_data: str = None,
    backfill_mode: str = None,
    flex_match_mode: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates settings for a FlexMatch matchmaking configuration. These changes affect all matches and game sessions that are created after the update. To update settings, specify the configuration name to be updated and provide the new settings.   Learn more    Design a FlexMatch matchmaker   Related actions   CreateMatchmakingConfiguration | DescribeMatchmakingConfigurations | UpdateMatchmakingConfiguration | DeleteMatchmakingConfiguration | CreateMatchmakingRuleSet | DescribeMatchmakingRuleSets | ValidateMatchmakingRuleSet | DeleteMatchmakingRuleSet | All APIs by task

    Args:
        name(str): A unique identifier for the matchmaking configuration to update. You can use either the configuration name or ARN value. .
        description(str, optional): A descriptive label that is associated with matchmaking configuration. Defaults to None.
        game_session_queue_arns(List, optional): The Amazon Resource Name (ARN) that is assigned to a GameLift game session queue resource and uniquely identifies it. ARNs are unique across all Regions. Format is arn:aws:gamelift:<region>::gamesessionqueue/<queue name>. Queues can be located in any Region. Queues are used to start new GameLift-hosted game sessions for matches that are created with this matchmaking configuration. If FlexMatchMode is set to STANDALONE, do not set this parameter. Defaults to None.
        request_timeout_seconds(int, optional): The maximum duration, in seconds, that a matchmaking ticket can remain in process before timing out. Requests that fail due to timing out can be resubmitted as needed. Defaults to None.
        acceptance_timeout_seconds(int, optional): The length of time (in seconds) to wait for players to accept a proposed match, if acceptance is required. Defaults to None.
        acceptance_required(bool, optional): A flag that indicates whether a match that was created with this configuration must be accepted by the matched players. To require acceptance, set to TRUE. With this option enabled, matchmaking tickets use the status REQUIRES_ACCEPTANCE to indicate when a completed potential match is waiting for player acceptance. . Defaults to None.
        rule_set_name(str, optional): A unique identifier for the matchmaking rule set to use with this configuration. You can use either the rule set name or ARN value. A matchmaking configuration can only use rule sets that are defined in the same Region. Defaults to None.
        notification_target(str, optional): An SNS topic ARN that is set up to receive matchmaking notifications. See  Setting up notifications for matchmaking for more information. Defaults to None.
        additional_player_count(int, optional): The number of player slots in a match to keep open for future players. For example, if the configuration's rule set specifies a match for a single 12-person team, and the additional player count is set to 2, only 10 players are selected for the match. This parameter is not used if FlexMatchMode is set to STANDALONE. Defaults to None.
        custom_event_data(str, optional): Information to add to all events related to the matchmaking configuration. . Defaults to None.
        game_properties(List, optional): A set of custom properties for a game session, formatted as key:value pairs. These properties are passed to a game server process in the GameSession object with a request to start a new game session (see Start a Game Session). This information is added to the new GameSession object that is created for a successful match. This parameter is not used if FlexMatchMode is set to STANDALONE. Defaults to None.
        game_session_data(str, optional): A set of custom game session properties, formatted as a single string value. This data is passed to a game server process in the GameSession object with a request to start a new game session (see Start a Game Session). This information is added to the new GameSession object that is created for a successful match. This parameter is not used if FlexMatchMode is set to STANDALONE. Defaults to None.
        backfill_mode(str, optional): The method that is used to backfill game sessions created with this matchmaking configuration. Specify MANUAL when your game manages backfill requests manually or does not use the match backfill feature. Specify AUTOMATIC to have GameLift create a StartMatchBackfill request whenever a game session has one or more open slots. Learn more about manual and automatic backfill in Backfill Existing Games with FlexMatch. Automatic backfill is not available when FlexMatchMode is set to STANDALONE. Defaults to None.
        flex_match_mode(str, optional): Indicates whether this matchmaking configuration is being used with GameLift hosting or as a standalone matchmaking solution.     STANDALONE - FlexMatch forms matches and returns match information, including players and team assignments, in a  MatchmakingSucceeded event.    WITH_QUEUE - FlexMatch forms matches and uses the specified GameLift queue to start a game session for the match.   . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.matchmaking.configuration.update(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.matchmaking.configuration.update name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="update_matchmaking_configuration",
        op_kwargs={
            "Name": name,
            "Description": description,
            "GameSessionQueueArns": game_session_queue_arns,
            "RequestTimeoutSeconds": request_timeout_seconds,
            "AcceptanceTimeoutSeconds": acceptance_timeout_seconds,
            "AcceptanceRequired": acceptance_required,
            "RuleSetName": rule_set_name,
            "NotificationTarget": notification_target,
            "AdditionalPlayerCount": additional_player_count,
            "CustomEventData": custom_event_data,
            "GameProperties": game_properties,
            "GameSessionData": game_session_data,
            "BackfillMode": backfill_mode,
            "FlexMatchMode": flex_match_mode,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, certificate: str, label: str = None) -> Dict:
    r"""
    **Autogenerated function**

    This is documentation for AWS CloudHSM Classic. For more information, see AWS CloudHSM Classic FAQs, the AWS CloudHSM Classic User Guide, and the AWS CloudHSM Classic API Reference.  For information about the current version of AWS CloudHSM, see AWS CloudHSM, the AWS CloudHSM User Guide, and the AWS CloudHSM API Reference. Creates an HSM client.

    Args:
        label(str, optional): The label for the client. Defaults to None.
        certificate(str): The contents of a Base64-Encoded X.509 v3 certificate to be installed on the HSMs used by this client.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudhsm.luna_client.create(ctx, certificate=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudhsm.luna_client.create certificate=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudhsm",
        operation="create_luna_client",
        op_kwargs={"Label": label, "Certificate": certificate},
    )


async def delete(hub, ctx, client_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    This is documentation for AWS CloudHSM Classic. For more information, see AWS CloudHSM Classic FAQs, the AWS CloudHSM Classic User Guide, and the AWS CloudHSM Classic API Reference.  For information about the current version of AWS CloudHSM, see AWS CloudHSM, the AWS CloudHSM User Guide, and the AWS CloudHSM API Reference. Deletes a client.

    Args:
        client_arn(str): The ARN of the client to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudhsm.luna_client.delete(ctx, client_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudhsm.luna_client.delete client_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudhsm",
        operation="delete_luna_client",
        op_kwargs={"ClientArn": client_arn},
    )


async def describe(
    hub, ctx, client_arn: str = None, certificate_fingerprint: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    This is documentation for AWS CloudHSM Classic. For more information, see AWS CloudHSM Classic FAQs, the AWS CloudHSM Classic User Guide, and the AWS CloudHSM Classic API Reference.  For information about the current version of AWS CloudHSM, see AWS CloudHSM, the AWS CloudHSM User Guide, and the AWS CloudHSM API Reference. Retrieves information about an HSM client.

    Args:
        client_arn(str, optional): The ARN of the client. Defaults to None.
        certificate_fingerprint(str, optional): The certificate fingerprint. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudhsm.luna_client.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudhsm.luna_client.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudhsm",
        operation="describe_luna_client",
        op_kwargs={
            "ClientArn": client_arn,
            "CertificateFingerprint": certificate_fingerprint,
        },
    )


async def list_all(hub, ctx, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    This is documentation for AWS CloudHSM Classic. For more information, see AWS CloudHSM Classic FAQs, the AWS CloudHSM Classic User Guide, and the AWS CloudHSM Classic API Reference.  For information about the current version of AWS CloudHSM, see AWS CloudHSM, the AWS CloudHSM User Guide, and the AWS CloudHSM API Reference. Lists all of the clients. This operation supports pagination with the use of the NextToken member. If more results are available, the NextToken member of the response contains a token that you pass in the next call to ListLunaClients to retrieve the next set of items.

    Args:
        next_token(str, optional): The NextToken value from a previous call to ListLunaClients. Pass null if this is the first call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudhsm.luna_client.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudhsm.luna_client.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudhsm",
        operation="list_luna_clients",
        op_kwargs={"NextToken": next_token},
    )


async def modify(hub, ctx, client_arn: str, certificate: str) -> Dict:
    r"""
    **Autogenerated function**

    This is documentation for AWS CloudHSM Classic. For more information, see AWS CloudHSM Classic FAQs, the AWS CloudHSM Classic User Guide, and the AWS CloudHSM Classic API Reference.  For information about the current version of AWS CloudHSM, see AWS CloudHSM, the AWS CloudHSM User Guide, and the AWS CloudHSM API Reference. Modifies the certificate used by the client. This action can potentially start a workflow to install the new certificate on the client's HSMs.

    Args:
        client_arn(str): The ARN of the client.
        certificate(str): The new certificate for the client.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudhsm.luna_client.modify(
                ctx, client_arn=value, certificate=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudhsm.luna_client.modify client_arn=value, certificate=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudhsm",
        operation="modify_luna_client",
        op_kwargs={"ClientArn": client_arn, "Certificate": certificate},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, target: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the Session Manager connection status for an instance to determine whether it is running and ready to receive Session Manager connections.

    Args:
        target(str): The ID of the instance.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.connection_status.get(ctx, target=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.connection_status.get target=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="get_connection_status",
        op_kwargs={"Target": target},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, lens_alias: str, base_lens_version: str) -> Dict:
    r"""
    **Autogenerated function**

    Get lens version differences.

    Args:
        lens_alias(str): The alias of the lens, for example, serverless. Each lens is identified by its LensSummary$LensAlias.
        base_lens_version(str): The base version of the lens.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wellarchitected.lens.version_difference.get(
                ctx, lens_alias=value, base_lens_version=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wellarchitected.lens.version_difference.get lens_alias=value, base_lens_version=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wellarchitected",
        operation="get_lens_version_difference",
        op_kwargs={"LensAlias": lens_alias, "BaseLensVersion": base_lens_version},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def invalidate(hub, ctx, project_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Resets the cache for a project.

    Args:
        project_name(str): The name of the AWS CodeBuild build project that the cache is reset for.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codebuild.project.cache.invalidate(ctx, project_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codebuild.project.cache.invalidate project_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codebuild",
        operation="invalidate_project_cache",
        op_kwargs={"projectName": project_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, channel_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Delete all schedule actions on a channel.

    Args:
        channel_id(str): Id of the channel whose schedule is being deleted.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.medialive.schedule.delete(ctx, channel_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.medialive.schedule.delete channel_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="medialive",
        operation="delete_schedule",
        op_kwargs={"ChannelId": channel_id},
    )


async def describe(
    hub, ctx, channel_id: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Get a channel schedule

    Args:
        channel_id(str): Id of the channel whose schedule is being updated.
        max_results(int, optional): Placeholder documentation for MaxResults. Defaults to None.
        next_token(str, optional): Placeholder documentation for __string. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.medialive.schedule.describe(ctx, channel_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.medialive.schedule.describe channel_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="medialive",
        operation="describe_schedule",
        op_kwargs={
            "ChannelId": channel_id,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(hub, ctx, schema_arn: str, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns the identity attribute order for a specific TypedLinkFacet. For more information, see Typed Links.

    Args:
        schema_arn(str): The Amazon Resource Name (ARN) that is associated with the schema. For more information, see arns.
        name(str): The unique name of the typed link facet.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.clouddirectory.typed_link.facet.information.get_all(
                ctx, schema_arn=value, name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.clouddirectory.typed_link.facet.information.get_all schema_arn=value, name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="clouddirectory",
        operation="get_typed_link_facet_information",
        op_kwargs={"SchemaArn": schema_arn, "Name": name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def associate(
    hub,
    ctx,
    cluster_name: str,
    encryption_config: List,
    client_request_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Associate encryption configuration to an existing cluster. You can use this API to enable encryption on existing clusters which do not have encryption already enabled. This allows you to implement a defense-in-depth security strategy without migrating applications to new Amazon EKS clusters.

    Args:
        cluster_name(str): The name of the cluster that you are associating with encryption configuration.
        encryption_config(List): The configuration you are using for encryption.
        client_request_token(str, optional): The client request token you are using with the encryption configuration. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.eks.encryption_config.associate(
                ctx, cluster_name=value, encryption_config=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.eks.encryption_config.associate cluster_name=value, encryption_config=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="eks",
        operation="associate_encryption_config",
        op_kwargs={
            "clusterName": cluster_name,
            "encryptionConfig": encryption_config,
            "clientRequestToken": client_request_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def deregister(hub, ctx, window_id: str, window_task_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Removes a task from a maintenance window.

    Args:
        window_id(str): The ID of the maintenance window the task should be removed from.
        window_task_id(str): The ID of the task to remove from the maintenance window.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.task.from_maintenance_window.deregister(
                ctx, window_id=value, window_task_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.task.from_maintenance_window.deregister window_id=value, window_task_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="deregister_task_from_maintenance_window",
        op_kwargs={"WindowId": window_id, "WindowTaskId": window_task_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(
    hub,
    ctx,
    resource_arn: str,
    secret_arn: str,
    sql: str,
    database: str = None,
    parameter_sets: List = None,
    schema: str = None,
    transaction_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Runs a batch SQL statement over an array of data. You can run bulk update and insert operations for multiple records using a DML statement with different parameter sets. Bulk operations can provide a significant performance improvement over individual insert and update operations.  If a call isn't part of a transaction because it doesn't include the transactionID parameter, changes that result from the call are committed automatically.

    Args:
        database(str, optional): The name of the database. Defaults to None.
        parameter_sets(List, optional): The parameter set for the batch operation. The SQL statement is executed as many times as the number of parameter sets provided. To execute a SQL statement with no parameters, use one of the following options:   Specify one or more empty parameter sets.   Use the ExecuteStatement operation instead of the BatchExecuteStatement operation.    Array parameters are not supported. . Defaults to None.
        resource_arn(str): The Amazon Resource Name (ARN) of the Aurora Serverless DB cluster.
        schema(str, optional): The name of the database schema. Defaults to None.
        secret_arn(str): The name or ARN of the secret that enables access to the DB cluster.
        sql(str): The SQL statement to run.
        transaction_id(str, optional): The identifier of a transaction that was started by using the BeginTransaction operation. Specify the transaction ID of the transaction that you want to include the SQL statement in. If the SQL statement is not part of a transaction, don't set this parameter. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds_data.execute_statement.batch(
                ctx, resource_arn=value, secret_arn=value, sql=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds_data.execute_statement.batch resource_arn=value, secret_arn=value, sql=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds-data",
        operation="batch_execute_statement",
        op_kwargs={
            "database": database,
            "parameterSets": parameter_sets,
            "resourceArn": resource_arn,
            "schema": schema,
            "secretArn": secret_arn,
            "sql": sql,
            "transactionId": transaction_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Returns the current service opt-in settings for the Region. If service-opt-in is enabled for a service, AWS Backup tries to protect that service's resources in this Region, when the resource is included in an on-demand backup or scheduled backup plan. Otherwise, AWS Backup does not try to protect that service's resources in this Region, AWS Backup does not try to protect that service's resources in this Region.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.backup.region_setting.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.backup.region_setting.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="backup", operation="describe_region_settings", op_kwargs={}
    )


async def update_multiple(
    hub, ctx, resource_type_opt_in_preference: Dict = None
) -> None:
    r"""
    **Autogenerated function**

    Updates the current service opt-in settings for the Region. If service-opt-in is enabled for a service, AWS Backup tries to protect that service's resources in this Region, when the resource is included in an on-demand backup or scheduled backup plan. Otherwise, AWS Backup does not try to protect that service's resources in this Region. Use the DescribeRegionSettings API to determine the resource types that are supported.

    Args:
        resource_type_opt_in_preference(Dict, optional): Updates the list of services along with the opt-in preferences for the Region. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.backup.region_setting.update_multiple(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.backup.region_setting.update_multiple
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="backup",
        operation="update_region_settings",
        op_kwargs={"ResourceTypeOptInPreference": resource_type_opt_in_preference},
    )
